/* header file containing declaration of parameters and
   functions to be used in face detection */


#ifndef MAIN_H
#define MAIN_H

#include <../../hal/lpc2106-cmucam3/cc3_hal.h>

/*----------------------------------------*/
/*          Declaring variables           */
/*----------------------------------------*/

/*------ struct for features--------*/
typedef struct 
{
  uint8_t x[9]; // x-coordinate 
  uint8_t y[9]; // y-coordinate
  int8_t val_at_corners[9]; // value of feature at (x,y)
  int8_t parity;             // parity (+1/-1)
  int32_t thresh;           // threshold for this feature
  int32_t alpha;           // alpha value
} cc3_feature;
/*
Note: Since the max image size is 352x288, the max scale for the features can be 288. 
But we'll never go upto that scale, so declaring (x,y) as uint8_t is sufficient
*/


/*---------- cmucam3 specific-------------*/

const uint16_t CC3_INTEGRAL_IMG_HEIGHT = 61; // height of integral image
const uint16_t CC3_INTEGRAL_IMG_WIDTH = CC3_LO_RES_WIDTH; // width of integral image

// the actual image size is 176x144 (low res)
// but for this the integral image doesn't fit into the memory, so 
// dropping off the some rows from top and bottom
const uint8_t CC3_IMAGE_HEIGHT = CC3_LO_RES_HEIGHT;        // height of the actual image

const uint8_t top_offset = 12; // discard some top rows from the actual image so that integral image can fit into memory
const uint8_t bottom_offset = 12; // similarly, discard some bottom rows in the actual image
// => the image size that the code sees is CC3_IMAGE_HEIGHT - top_offset - bottom_offset 

//int32_t cc3_integral_image[CC3_INTEGRAL_IMG_HEIGHT][CC3_INTEGRAL_IMG_WIDTH];
uint32_t cc3_integral_image[61][176];
    
const uint8_t CC3_NUM_SCALES = 4;            // no. of scales of sub-windows allowed
const uint8_t CC3_SCALES[] = {31, 39, 49, 61}; // array containing different scales  (assuming no. of scales = 4)
const uint8_t CC3_WIN_STEPS[]={2, 2, 4, 4}; // array containing "window step" for each scale

const uint8_t CC3_SCALING_FACTOR = 100;

/*----------- face detector specific--------*/

const uint8_t CC3_NUM_CASCADES = 5;

// array of global thresholds (from adaboost) - whether a face or not (NOTE: alphas have been scaled..!!!)
// (one for each cascade stage)
const int16_t CC3_GLOBAL_THRESHOLD[] = {444, 294, 581, 1180, 1355};

const uint8_t CC3_NUM_FEATURES[] = {9, 10, 25, 100, 100};   // no. of features 

// size-->[CC3_IMAGE_HEIGHT][NUM_SCALES]
const uint8_t cc3_rows_to_eval_feat[120][4] = { 
{ 1, 1, 1, 1 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 },
{ 1, 1, 1, 1 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 1, 1 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 1, 1 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 1, 1 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 1, 1 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 1, 1 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 1, 1 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 1, 1 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 1, 1 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 1, 1 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 1, 1 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 1, 1 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 1, 1 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 1, 1 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 1, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 1, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 1, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 1, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 1, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
{ 0, 0, 0, 0 }, 
 };



/*--------------initializing features-------*/

//    ------> x
//    |
//    | 
// y  v
// dimensions: 1. Number of features 2. Each feature at all the scales

const cc3_feature CC3_FACE_FEATURES0[9][4] = { 
{ 
{ {4, 4, 4, 25, 25, 25, 0, 0, 0}, {7, 12, 17, 7, 12, 17, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1101,  124 }, 
{ {5, 5, 5, 32, 32, 32, 0, 0, 0}, {9, 15, 21, 9, 15, 21, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1101,  124 }, 
{ {7, 7, 7, 41, 41, 41, 0, 0, 0}, {11, 19, 27, 11, 19, 27, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1101,  124 }, 
{ {9, 9, 9, 52, 52, 52, 0, 0, 0}, {14, 24, 34, 14, 24, 34, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1101,  124 }, 
}, 
{ 
{ {3, 3, 12, 12, 21, 21, 30, 30, 0}, {0, 10, 0, 10, 0, 10, 0, 10, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -3650,  106 }, 
{ {4, 4, 15, 15, 26, 26, 37, 37, 0}, {0, 13, 0, 13, 0, 13, 0, 13, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -3650,  106 }, 
{ {5, 5, 19, 19, 33, 33, 47, 47, 0}, {0, 16, 0, 16, 0, 16, 0, 16, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -3650,  106 }, 
{ {6, 6, 24, 24, 42, 42, 60, 60, 0}, {0, 20, 0, 20, 0, 20, 0, 20, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -3650,  106 }, 
}, 
{ 
{ {0, 0, 0, 10, 10, 10, 0, 0, 0}, {0, 5, 10, 0, 5, 10, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -568300,   63 }, 
{ {0, 0, 0, 13, 13, 13, 0, 0, 0}, {0, 6, 12, 0, 6, 12, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -568300,   63 }, 
{ {0, 0, 0, 16, 16, 16, 0, 0, 0}, {0, 8, 16, 0, 8, 16, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -568300,   63 }, 
{ {0, 0, 0, 20, 20, 20, 0, 0, 0}, {0, 10, 20, 0, 10, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -568300,   63 }, 
}, 
{ 
{ {5, 5, 5, 25, 25, 25, 0, 0, 0}, {13, 18, 23, 13, 18, 23, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  100,   84 }, 
{ {7, 7, 7, 32, 32, 32, 0, 0, 0}, {16, 22, 28, 16, 22, 28, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  100,   84 }, 
{ {9, 9, 9, 41, 41, 41, 0, 0, 0}, {21, 29, 37, 21, 29, 37, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  100,   84 }, 
{ {12, 12, 12, 52, 52, 52, 0, 0, 0}, {27, 37, 47, 27, 37, 47, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  100,   84 }, 
}, 
{ 
{ {3, 3, 3, 8, 8, 8, 13, 13, 13}, {2, 7, 12, 2, 7, 12, 2, 7, 12}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -224,   64 }, 
{ {4, 4, 4, 10, 10, 10, 16, 16, 16}, {2, 8, 14, 2, 8, 14, 2, 8, 14}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -224,   64 }, 
{ {5, 5, 5, 13, 13, 13, 21, 21, 21}, {3, 11, 19, 3, 11, 19, 3, 11, 19}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -224,   64 }, 
{ {7, 7, 7, 17, 17, 17, 27, 27, 27}, {4, 14, 24, 4, 14, 24, 4, 14, 24}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -224,   64 }, 
}, 
{ 
{ {13, 13, 13, 18, 18, 18, 23, 23, 23}, {7, 13, 19, 7, 13, 19, 7, 13, 19}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  308,   55 }, 
{ {16, 16, 16, 22, 22, 22, 28, 28, 28}, {9, 17, 25, 9, 17, 25, 9, 17, 25}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  308,   55 }, 
{ {21, 21, 21, 29, 29, 29, 37, 37, 37}, {11, 21, 31, 11, 21, 31, 11, 21, 31}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  308,   55 }, 
{ {27, 27, 27, 37, 37, 37, 47, 47, 47}, {14, 27, 40, 14, 27, 40, 14, 27, 40}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  308,   55 }, 
}, 
{ 
{ {12, 12, 12, 26, 26, 26, 0, 0, 0}, {13, 19, 25, 13, 19, 25, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 6299,   81 }, 
{ {15, 15, 15, 32, 32, 32, 0, 0, 0}, {16, 24, 32, 16, 24, 32, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 6299,   81 }, 
{ {19, 19, 19, 41, 41, 41, 0, 0, 0}, {21, 31, 41, 21, 31, 41, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 6299,   81 }, 
{ {24, 24, 24, 52, 52, 52, 0, 0, 0}, {27, 40, 53, 27, 40, 53, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 6299,   81 }, 
}, 
{ 
{ {20, 20, 25, 25, 30, 30, 0, 0, 0}, {0, 24, 0, 24, 0, 24, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 2307,   60 }, 
{ {26, 26, 32, 32, 38, 38, 0, 0, 0}, {0, 30, 0, 30, 0, 30, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 2307,   60 }, 
{ {32, 32, 40, 40, 48, 48, 0, 0, 0}, {0, 38, 0, 38, 0, 38, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 2307,   60 }, 
{ {40, 40, 50, 50, 60, 60, 0, 0, 0}, {0, 48, 0, 48, 0, 48, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 2307,   60 }, 
}, 
{ 
{ {14, 14, 18, 18, 22, 22, 26, 26, 0}, {7, 23, 7, 23, 7, 23, 7, 23, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  219,   50 }, 
{ {18, 18, 23, 23, 28, 28, 33, 33, 0}, {9, 30, 9, 30, 9, 30, 9, 30, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  219,   50 }, 
{ {23, 23, 29, 29, 35, 35, 41, 41, 0}, {11, 37, 11, 37, 11, 37, 11, 37, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  219,   50 }, 
{ {29, 29, 37, 37, 45, 45, 53, 53, 0}, {14, 47, 14, 47, 14, 47, 14, 47, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  219,   50 }, 
}, 
};


const cc3_feature CC3_FACE_FEATURES1[10][4] = { 
{ 
{ {2, 2, 2, 26, 26, 26, 0, 0, 0}, {7, 12, 17, 7, 12, 17, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -504,  118 }, 
{ {2, 2, 2, 32, 32, 32, 0, 0, 0}, {9, 15, 21, 9, 15, 21, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -504,  118 }, 
{ {3, 3, 3, 41, 41, 41, 0, 0, 0}, {11, 19, 27, 11, 19, 27, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -504,  118 }, 
{ {4, 4, 4, 52, 52, 52, 0, 0, 0}, {14, 24, 34, 14, 24, 34, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -504,  118 }, 
}, 
{ 
{ {2, 2, 2, 27, 27, 27, 0, 0, 0}, {4, 12, 20, 4, 12, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -12892,   76 }, 
{ {2, 2, 2, 34, 34, 34, 0, 0, 0}, {5, 15, 25, 5, 15, 25, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -12892,   76 }, 
{ {3, 3, 3, 43, 43, 43, 0, 0, 0}, {7, 19, 31, 7, 19, 31, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -12892,   76 }, 
{ {4, 4, 4, 54, 54, 54, 0, 0, 0}, {9, 24, 39, 9, 24, 39, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -12892,   76 }, 
}, 
{ 
{ {20, 20, 25, 25, 30, 30, 0, 0, 0}, {0, 18, 0, 18, 0, 18, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 1720,   66 }, 
{ {26, 26, 32, 32, 38, 38, 0, 0, 0}, {0, 22, 0, 22, 0, 22, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 1720,   66 }, 
{ {32, 32, 40, 40, 48, 48, 0, 0, 0}, {0, 28, 0, 28, 0, 28, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 1720,   66 }, 
{ {40, 40, 50, 50, 60, 60, 0, 0, 0}, {0, 35, 0, 35, 0, 35, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 1720,   66 }, 
}, 
{ 
{ {18, 18, 18, 23, 23, 23, 28, 28, 28}, {2, 7, 12, 2, 7, 12, 2, 7, 12}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  202,   49 }, 
{ {23, 23, 23, 29, 29, 29, 35, 35, 35}, {2, 8, 14, 2, 8, 14, 2, 8, 14}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  202,   49 }, 
{ {29, 29, 29, 37, 37, 37, 45, 45, 45}, {3, 11, 19, 3, 11, 19, 3, 11, 19}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  202,   49 }, 
{ {37, 37, 37, 47, 47, 47, 57, 57, 57}, {4, 14, 24, 4, 14, 24, 4, 14, 24}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  202,   49 }, 
}, 
{ 
{ {3, 3, 3, 8, 8, 8, 13, 13, 13}, {0, 6, 12, 0, 6, 12, 0, 6, 12}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -302,   37 }, 
{ {4, 4, 4, 10, 10, 10, 16, 16, 16}, {0, 8, 16, 0, 8, 16, 0, 8, 16}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -302,   37 }, 
{ {5, 5, 5, 13, 13, 13, 21, 21, 21}, {0, 10, 20, 0, 10, 20, 0, 10, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -302,   37 }, 
{ {7, 7, 7, 17, 17, 17, 27, 27, 27}, {0, 13, 26, 0, 13, 26, 0, 13, 26}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -302,   37 }, 
}, 
{ 
{ {4, 4, 4, 14, 14, 14, 0, 0, 0}, {13, 18, 23, 13, 18, 23, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,   51,   29 }, 
{ {5, 5, 5, 18, 18, 18, 0, 0, 0}, {16, 22, 28, 16, 22, 28, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,   51,   29 }, 
{ {7, 7, 7, 23, 23, 23, 0, 0, 0}, {21, 29, 37, 21, 29, 37, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,   51,   29 }, 
{ {9, 9, 9, 29, 29, 29, 0, 0, 0}, {27, 37, 47, 27, 37, 47, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,   51,   29 }, 
}, 
{ 
{ {17, 17, 17, 30, 30, 30, 0, 0, 0}, {5, 11, 17, 5, 11, 17, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -149,   28 }, 
{ {22, 22, 22, 38, 38, 38, 0, 0, 0}, {7, 15, 23, 7, 15, 23, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -149,   28 }, 
{ {28, 28, 28, 48, 48, 48, 0, 0, 0}, {9, 19, 29, 9, 19, 29, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -149,   28 }, 
{ {35, 35, 35, 60, 60, 60, 0, 0, 0}, {12, 25, 38, 12, 25, 38, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -149,   28 }, 
}, 
{ 
{ {2, 2, 2, 15, 15, 15, 28, 28, 28}, {10, 16, 22, 10, 16, 22, 10, 16, 22}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 2499,   13 }, 
{ {2, 2, 2, 18, 18, 18, 34, 34, 34}, {13, 21, 29, 13, 21, 29, 13, 21, 29}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 2499,   13 }, 
{ {3, 3, 3, 23, 23, 23, 43, 43, 43}, {17, 27, 37, 17, 27, 37, 17, 27, 37}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 2499,   13 }, 
{ {4, 4, 4, 29, 29, 29, 54, 54, 54}, {22, 35, 48, 22, 35, 48, 22, 35, 48}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 2499,   13 }, 
}, 
{ 
{ {0, 0, 0, 29, 29, 29, 0, 0, 0}, {7, 18, 29, 7, 18, 29, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 18398,    7 }, 
{ {0, 0, 0, 36, 36, 36, 0, 0, 0}, {9, 23, 37, 9, 23, 37, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 18398,    7 }, 
{ {0, 0, 0, 46, 46, 46, 0, 0, 0}, {11, 29, 47, 11, 29, 47, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 18398,    7 }, 
{ {0, 0, 0, 58, 58, 58, 0, 0, 0}, {14, 37, 60, 14, 37, 60, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 18398,    7 }, 
}, 
{ 
{ {0, 0, 0, 10, 10, 10, 0, 0, 0}, {0, 5, 10, 0, 5, 10, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -568300,  164 }, 
{ {0, 0, 0, 13, 13, 13, 0, 0, 0}, {0, 6, 12, 0, 6, 12, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -568300,  164 }, 
{ {0, 0, 0, 16, 16, 16, 0, 0, 0}, {0, 8, 16, 0, 8, 16, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -568300,  164 }, 
{ {0, 0, 0, 20, 20, 20, 0, 0, 0}, {0, 10, 20, 0, 10, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -568300,  164 }, 
}, 
};

const cc3_feature CC3_FACE_FEATURES2[25][4] = { 
{ 
{ {0, 0, 5, 5, 10, 10, 0, 0, 0}, {0, 20, 0, 20, 0, 20, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -2667,   88 }, 
{ {0, 0, 6, 6, 12, 12, 0, 0, 0}, {0, 25, 0, 25, 0, 25, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -2667,   88 }, 
{ {0, 0, 8, 8, 16, 16, 0, 0, 0}, {0, 32, 0, 32, 0, 32, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -2667,   88 }, 
{ {0, 0, 10, 10, 20, 20, 0, 0, 0}, {0, 40, 0, 40, 0, 40, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -2667,   88 }, 
}, 
{ 
{ {8, 8, 8, 13, 13, 13, 18, 18, 18}, {7, 13, 19, 7, 13, 19, 7, 13, 19}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -503,   82 }, 
{ {10, 10, 10, 16, 16, 16, 22, 22, 22}, {9, 17, 25, 9, 17, 25, 9, 17, 25}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -503,   82 }, 
{ {13, 13, 13, 21, 21, 21, 29, 29, 29}, {11, 21, 31, 11, 21, 31, 11, 21, 31}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -503,   82 }, 
{ {17, 17, 17, 27, 27, 27, 37, 37, 37}, {14, 27, 40, 14, 27, 40, 14, 27, 40}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -503,   82 }, 
}, 
{ 
{ {7, 7, 7, 22, 22, 22, 0, 0, 0}, {2, 7, 12, 2, 7, 12, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, 1515,   66 }, 
{ {9, 9, 9, 28, 28, 28, 0, 0, 0}, {2, 8, 14, 2, 8, 14, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, 1515,   66 }, 
{ {11, 11, 11, 35, 35, 35, 0, 0, 0}, {3, 11, 19, 3, 11, 19, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, 1515,   66 }, 
{ {14, 14, 14, 44, 44, 44, 0, 0, 0}, {4, 14, 24, 4, 14, 24, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, 1515,   66 }, 
}, 
{ 
{ {17, 17, 17, 22, 22, 22, 27, 27, 27}, {8, 18, 28, 8, 18, 28, 8, 18, 28}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -146,   54 }, 
{ {21, 21, 21, 27, 27, 27, 33, 33, 33}, {10, 23, 36, 10, 23, 36, 10, 23, 36}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -146,   54 }, 
{ {27, 27, 27, 35, 35, 35, 43, 43, 43}, {13, 29, 45, 13, 29, 45, 13, 29, 45}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -146,   54 }, 
{ {34, 34, 34, 44, 44, 44, 54, 54, 54}, {17, 37, 57, 17, 37, 57, 17, 37, 57}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -146,   54 }, 
}, 
{ 
{ {5, 5, 5, 10, 10, 10, 15, 15, 15}, {19, 24, 29, 19, 24, 29, 19, 24, 29}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  342,   51 }, 
{ {7, 7, 7, 13, 13, 13, 19, 19, 19}, {24, 30, 36, 24, 30, 36, 24, 30, 36}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  342,   51 }, 
{ {9, 9, 9, 17, 17, 17, 25, 25, 25}, {31, 39, 47, 31, 39, 47, 31, 39, 47}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  342,   51 }, 
{ {12, 12, 12, 22, 22, 22, 32, 32, 32}, {39, 49, 59, 39, 49, 59, 39, 49, 59}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  342,   51 }, 
}, 
{ 
{ {8, 8, 8, 16, 16, 16, 24, 24, 24}, {13, 18, 23, 13, 18, 23, 13, 18, 23}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  866,   43 }, 
{ {10, 10, 10, 20, 20, 20, 30, 30, 30}, {16, 22, 28, 16, 22, 28, 16, 22, 28}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  866,   43 }, 
{ {13, 13, 13, 25, 25, 25, 37, 37, 37}, {21, 29, 37, 21, 29, 37, 21, 29, 37}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  866,   43 }, 
{ {17, 17, 17, 32, 32, 32, 47, 47, 47}, {27, 37, 47, 27, 37, 47, 27, 37, 47}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  866,   43 }, 
}, 
{ 
{ {9, 9, 13, 13, 17, 17, 21, 21, 0}, {5, 16, 5, 16, 5, 16, 5, 16, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1389,   43 }, 
{ {12, 12, 17, 17, 22, 22, 27, 27, 0}, {7, 21, 7, 21, 7, 21, 7, 21, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1389,   43 }, 
{ {15, 15, 21, 21, 27, 27, 33, 33, 0}, {9, 27, 9, 27, 9, 27, 9, 27, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1389,   43 }, 
{ {19, 19, 27, 27, 35, 35, 43, 43, 0}, {12, 35, 12, 35, 12, 35, 12, 35, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1389,   43 }, 
}, 
{ 
{ {15, 15, 15, 20, 20, 20, 25, 25, 25}, {19, 24, 29, 19, 24, 29, 19, 24, 29}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -614,   38 }, 
{ {20, 20, 20, 26, 26, 26, 32, 32, 32}, {24, 30, 36, 24, 30, 36, 24, 30, 36}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -614,   38 }, 
{ {25, 25, 25, 33, 33, 33, 41, 41, 41}, {31, 39, 47, 31, 39, 47, 31, 39, 47}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -614,   38 }, 
{ {32, 32, 32, 42, 42, 42, 52, 52, 52}, {39, 49, 59, 39, 49, 59, 39, 49, 59}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -614,   38 }, 
}, 
{ 
{ {7, 7, 7, 16, 16, 16, 25, 25, 25}, {12, 18, 24, 12, 18, 24, 12, 18, 24}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1179,   36 }, 
{ {9, 9, 9, 20, 20, 20, 31, 31, 31}, {15, 23, 31, 15, 23, 31, 15, 23, 31}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1179,   36 }, 
{ {11, 11, 11, 25, 25, 25, 39, 39, 39}, {19, 29, 39, 19, 29, 39, 19, 29, 39}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1179,   36 }, 
{ {14, 14, 14, 32, 32, 32, 50, 50, 50}, {24, 37, 50, 24, 37, 50, 24, 37, 50}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1179,   36 }, 
}, 
{ 
{ {0, 0, 4, 4, 8, 8, 12, 12, 0}, {17, 30, 17, 30, 17, 30, 17, 30, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, 1102,   34 }, 
{ {0, 0, 5, 5, 10, 10, 15, 15, 0}, {22, 38, 22, 38, 22, 38, 22, 38, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, 1102,   34 }, 
{ {0, 0, 6, 6, 12, 12, 18, 18, 0}, {28, 48, 28, 48, 28, 48, 28, 48, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, 1102,   34 }, 
{ {0, 0, 8, 8, 16, 16, 24, 24, 0}, {35, 60, 35, 60, 35, 60, 35, 60, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, 1102,   34 }, 
}, 
{ 
{ {7, 7, 11, 11, 15, 15, 19, 19, 0}, {9, 24, 9, 24, 9, 24, 9, 24, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  256,   32 }, 
{ {9, 9, 14, 14, 19, 19, 24, 24, 0}, {12, 31, 12, 31, 12, 31, 12, 31, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  256,   32 }, 
{ {11, 11, 17, 17, 23, 23, 29, 29, 0}, {15, 39, 15, 39, 15, 39, 15, 39, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  256,   32 }, 
{ {14, 14, 22, 22, 30, 30, 38, 38, 0}, {19, 49, 19, 49, 19, 49, 19, 49, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  256,   32 }, 
}, 
{ 
{ {2, 2, 2, 7, 7, 7, 12, 12, 12}, {7, 12, 17, 7, 12, 17, 7, 12, 17}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  370,   32 }, 
{ {2, 2, 2, 8, 8, 8, 14, 14, 14}, {9, 15, 21, 9, 15, 21, 9, 15, 21}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  370,   32 }, 
{ {3, 3, 3, 11, 11, 11, 19, 19, 19}, {11, 19, 27, 11, 19, 27, 11, 19, 27}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  370,   32 }, 
{ {4, 4, 4, 14, 14, 14, 24, 24, 24}, {14, 24, 34, 14, 24, 34, 14, 24, 34}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  370,   32 }, 
}, 
{ 
{ {19, 19, 19, 24, 24, 24, 29, 29, 29}, {20, 25, 30, 20, 25, 30, 20, 25, 30}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  710,   29 }, 
{ {24, 24, 24, 30, 30, 30, 36, 36, 36}, {26, 32, 38, 26, 32, 38, 26, 32, 38}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  710,   29 }, 
{ {31, 31, 31, 39, 39, 39, 47, 47, 47}, {32, 40, 48, 32, 40, 48, 32, 40, 48}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  710,   29 }, 
{ {39, 39, 39, 49, 49, 49, 59, 59, 59}, {40, 50, 60, 40, 50, 60, 40, 50, 60}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  710,   29 }, 
}, 
{ 
{ {0, 0, 0, 15, 15, 15, 30, 30, 30}, {7, 13, 19, 7, 13, 19, 7, 13, 19}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 2025,   32 }, 
{ {0, 0, 0, 19, 19, 19, 38, 38, 38}, {9, 17, 25, 9, 17, 25, 9, 17, 25}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 2025,   32 }, 
{ {0, 0, 0, 24, 24, 24, 48, 48, 48}, {11, 21, 31, 11, 21, 31, 11, 21, 31}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 2025,   32 }, 
{ {0, 0, 0, 30, 30, 30, 60, 60, 60}, {14, 27, 40, 14, 27, 40, 14, 27, 40}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 2025,   32 }, 
}, 
{ 
{ {4, 4, 4, 14, 14, 14, 24, 24, 24}, {8, 13, 18, 8, 13, 18, 8, 13, 18}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1378,   29 }, 
{ {5, 5, 5, 18, 18, 18, 31, 31, 31}, {10, 16, 22, 10, 16, 22, 10, 16, 22}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1378,   29 }, 
{ {7, 7, 7, 23, 23, 23, 39, 39, 39}, {13, 21, 29, 13, 21, 29, 13, 21, 29}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1378,   29 }, 
{ {9, 9, 9, 29, 29, 29, 49, 49, 49}, {17, 27, 37, 17, 27, 37, 17, 27, 37}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1378,   29 }, 
}, 
{ 
{ {17, 17, 17, 27, 27, 27, 0, 0, 0}, {12, 17, 22, 12, 17, 22, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  212,   16 }, 
{ {21, 21, 21, 34, 34, 34, 0, 0, 0}, {15, 21, 27, 15, 21, 27, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  212,   16 }, 
{ {27, 27, 27, 43, 43, 43, 0, 0, 0}, {19, 27, 35, 19, 27, 35, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  212,   16 }, 
{ {34, 34, 34, 54, 54, 54, 0, 0, 0}, {24, 34, 44, 24, 34, 44, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  212,   16 }, 
}, 
{ 
{ {8, 8, 8, 22, 22, 22, 0, 0, 0}, {5, 10, 15, 5, 10, 15, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -2360,   32 }, 
{ {10, 10, 10, 27, 27, 27, 0, 0, 0}, {7, 13, 19, 7, 13, 19, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -2360,   32 }, 
{ {13, 13, 13, 35, 35, 35, 0, 0, 0}, {9, 17, 25, 9, 17, 25, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -2360,   32 }, 
{ {17, 17, 17, 45, 45, 45, 0, 0, 0}, {12, 22, 32, 12, 22, 32, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -2360,   32 }, 
}, 
{ 
{ {8, 8, 8, 19, 19, 19, 30, 30, 30}, {3, 11, 19, 3, 11, 19, 3, 11, 19}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  612,   19 }, 
{ {10, 10, 10, 24, 24, 24, 38, 38, 38}, {4, 14, 24, 4, 14, 24, 4, 14, 24}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  612,   19 }, 
{ {12, 12, 12, 30, 30, 30, 48, 48, 48}, {5, 17, 29, 5, 17, 29, 5, 17, 29}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  612,   19 }, 
{ {14, 14, 14, 37, 37, 37, 60, 60, 60}, {7, 22, 37, 7, 22, 37, 7, 22, 37}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  612,   19 }, 
}, 
{ 
{ {10, 10, 10, 15, 15, 15, 20, 20, 20}, {15, 20, 25, 15, 20, 25, 15, 20, 25}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  600,   14 }, 
{ {13, 13, 13, 19, 19, 19, 25, 25, 25}, {20, 26, 32, 20, 26, 32, 20, 26, 32}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  600,   14 }, 
{ {17, 17, 17, 25, 25, 25, 33, 33, 33}, {25, 33, 41, 25, 33, 41, 25, 33, 41}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  600,   14 }, 
{ {22, 22, 22, 32, 32, 32, 42, 42, 42}, {32, 42, 52, 32, 42, 52, 32, 42, 52}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  600,   14 }, 
}, 
{ 
{ {0, 0, 0, 13, 13, 13, 26, 26, 26}, {3, 12, 21, 3, 12, 21, 3, 12, 21}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  354,   11 }, 
{ {0, 0, 0, 16, 16, 16, 32, 32, 32}, {4, 15, 26, 4, 15, 26, 4, 15, 26}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  354,   11 }, 
{ {0, 0, 0, 20, 20, 20, 40, 40, 40}, {5, 19, 33, 5, 19, 33, 5, 19, 33}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  354,   11 }, 
{ {0, 0, 0, 25, 25, 25, 50, 50, 50}, {7, 25, 43, 7, 25, 43, 7, 25, 43}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  354,   11 }, 
}, 
{ 
{ {4, 4, 4, 13, 13, 13, 22, 22, 22}, {8, 14, 20, 8, 14, 20, 8, 14, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1545,   10 }, 
{ {5, 5, 5, 16, 16, 16, 27, 27, 27}, {10, 18, 26, 10, 18, 26, 10, 18, 26}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1545,   10 }, 
{ {7, 7, 7, 21, 21, 21, 35, 35, 35}, {13, 23, 33, 13, 23, 33, 13, 23, 33}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1545,   10 }, 
{ {9, 9, 9, 27, 27, 27, 45, 45, 45}, {17, 30, 43, 17, 30, 43, 17, 30, 43}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1545,   10 }, 
}, 
{ 
{ {4, 4, 4, 25, 25, 25, 0, 0, 0}, {7, 12, 17, 7, 12, 17, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -1079,   82 }, 
{ {5, 5, 5, 32, 32, 32, 0, 0, 0}, {9, 15, 21, 9, 15, 21, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -1079,   82 }, 
{ {7, 7, 7, 41, 41, 41, 0, 0, 0}, {11, 19, 27, 11, 19, 27, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -1079,   82 }, 
{ {9, 9, 9, 52, 52, 52, 0, 0, 0}, {14, 24, 34, 14, 24, 34, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -1079,   82 }, 
}, 
{ 
{ {8, 8, 8, 18, 18, 18, 28, 28, 28}, {4, 12, 20, 4, 12, 20, 4, 12, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 4392,   39 }, 
{ {10, 10, 10, 23, 23, 23, 36, 36, 36}, {5, 15, 25, 5, 15, 25, 5, 15, 25}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 4392,   39 }, 
{ {13, 13, 13, 29, 29, 29, 45, 45, 45}, {7, 19, 31, 7, 19, 31, 7, 19, 31}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 4392,   39 }, 
{ {17, 17, 17, 37, 37, 37, 57, 57, 57}, {9, 24, 39, 9, 24, 39, 9, 24, 39}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 4392,   39 }, 
}, 
{ 
{ {17, 17, 17, 30, 30, 30, 0, 0, 0}, {0, 10, 20, 0, 10, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1895,   24 }, 
{ {22, 22, 22, 38, 38, 38, 0, 0, 0}, {0, 13, 26, 0, 13, 26, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1895,   24 }, 
{ {28, 28, 28, 48, 48, 48, 0, 0, 0}, {0, 16, 32, 0, 16, 32, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1895,   24 }, 
{ {35, 35, 35, 60, 60, 60, 0, 0, 0}, {0, 20, 40, 0, 20, 40, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1895,   24 }, 
}, 
{ 
{ {10, 10, 10, 26, 26, 26, 0, 0, 0}, {3, 8, 13, 3, 8, 13, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, 1792,   25 }, 
{ {13, 13, 13, 34, 34, 34, 0, 0, 0}, {4, 10, 16, 4, 10, 16, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, 1792,   25 }, 
{ {17, 17, 17, 43, 43, 43, 0, 0, 0}, {5, 13, 21, 5, 13, 21, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, 1792,   25 }, 
{ {22, 22, 22, 55, 55, 55, 0, 0, 0}, {7, 17, 27, 7, 17, 27, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, 1792,   25 }, 
}, 
};

const cc3_feature CC3_FACE_FEATURES3[100][4] = { 
{ 
{ {0, 0, 10, 10, 20, 20, 30, 30, 0}, {0, 29, 0, 29, 0, 29, 0, 29, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -16500,   73 }, 
{ {12, 12, 25, 25, 38, 38, 0, 0, 0}, {0, 36, 0, 36, 0, 36, 0, 0, 0}, {-3, 3, 3, -3, -1, 1, 0, 0, 0}, 1, -16500,   73 }, 
{ {0, 0, 16, 16, 32, 32, 48, 48, 0}, {0, 46, 0, 46, 0, 46, 0, 46, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -16500,   73 }, 
{ {0, 0, 20, 20, 40, 40, 60, 60, 0}, {0, 58, 0, 58, 0, 58, 0, 58, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -16500,   73 }, 
}, 
{ 
{ {15, 15, 15, 25, 25, 25, 0, 0, 0}, {7, 12, 17, 7, 12, 17, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1214,   53 }, 
{ {20, 20, 20, 33, 33, 33, 0, 0, 0}, {9, 15, 21, 9, 15, 21, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1214,   53 }, 
{ {25, 25, 25, 41, 41, 41, 0, 0, 0}, {11, 19, 27, 11, 19, 27, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1214,   53 }, 
{ {32, 32, 32, 52, 52, 52, 0, 0, 0}, {14, 24, 34, 14, 24, 34, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1214,   53 }, 
}, 
{ 
{ {9, 9, 9, 19, 19, 19, 0, 0, 0}, {4, 14, 24, 4, 14, 24, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -488,   46 }, 
{ {12, 12, 12, 25, 25, 25, 0, 0, 0}, {5, 18, 31, 5, 18, 31, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -488,   46 }, 
{ {15, 15, 15, 31, 31, 31, 0, 0, 0}, {7, 23, 39, 7, 23, 39, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -488,   46 }, 
{ {19, 19, 19, 39, 39, 39, 0, 0, 0}, {9, 29, 49, 9, 29, 49, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -488,   46 }, 
}, 
{ 
{ {20, 20, 25, 25, 30, 30, 0, 0, 0}, {0, 24, 0, 24, 0, 24, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 5254,   46 }, 
{ {26, 26, 32, 32, 38, 38, 0, 0, 0}, {0, 30, 0, 30, 0, 30, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 5254,   46 }, 
{ {32, 32, 40, 40, 48, 48, 0, 0, 0}, {0, 38, 0, 38, 0, 38, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 5254,   46 }, 
{ {40, 40, 50, 50, 60, 60, 0, 0, 0}, {0, 48, 0, 48, 0, 48, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 5254,   46 }, 
}, 
{ 
{ {5, 5, 5, 16, 16, 16, 27, 27, 27}, {12, 17, 22, 12, 17, 22, 12, 17, 22}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1138,   40 }, 
{ {7, 7, 7, 21, 21, 21, 35, 35, 35}, {15, 21, 27, 15, 21, 27, 15, 21, 27}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1138,   40 }, 
{ {9, 9, 9, 27, 27, 27, 45, 45, 45}, {19, 27, 35, 19, 27, 35, 19, 27, 35}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1138,   40 }, 
{ {12, 12, 12, 35, 35, 35, 58, 58, 58}, {24, 34, 44, 24, 34, 44, 24, 34, 44}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1138,   40 }, 
}, 
{ 
{ {19, 19, 19, 24, 24, 24, 29, 29, 29}, {0, 5, 10, 0, 5, 10, 0, 5, 10}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  849,   39 }, 
{ {24, 24, 24, 30, 30, 30, 36, 36, 36}, {0, 6, 12, 0, 6, 12, 0, 6, 12}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  849,   39 }, 
{ {31, 31, 31, 39, 39, 39, 47, 47, 47}, {0, 8, 16, 0, 8, 16, 0, 8, 16}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  849,   39 }, 
{ {39, 39, 39, 49, 49, 49, 59, 59, 59}, {0, 10, 20, 0, 10, 20, 0, 10, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  849,   39 }, 
}, 
{ 
{ {0, 0, 5, 5, 10, 10, 0, 0, 0}, {10, 25, 10, 25, 10, 25, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -4318,   32 }, 
{ {0, 0, 6, 6, 12, 12, 0, 0, 0}, {13, 32, 13, 32, 13, 32, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -4318,   32 }, 
{ {0, 0, 8, 8, 16, 16, 0, 0, 0}, {17, 41, 17, 41, 17, 41, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -4318,   32 }, 
{ {0, 0, 10, 10, 20, 20, 0, 0, 0}, {22, 52, 22, 52, 22, 52, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -4318,   32 }, 
}, 
{ 
{ {7, 7, 7, 16, 16, 16, 25, 25, 25}, {8, 16, 24, 8, 16, 24, 8, 16, 24}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1024,   39 }, 
{ {9, 9, 9, 20, 20, 20, 31, 31, 31}, {10, 20, 30, 10, 20, 30, 10, 20, 30}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1024,   39 }, 
{ {11, 11, 11, 25, 25, 25, 39, 39, 39}, {13, 25, 37, 13, 25, 37, 13, 25, 37}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1024,   39 }, 
{ {14, 14, 14, 32, 32, 32, 50, 50, 50}, {17, 32, 47, 17, 32, 47, 17, 32, 47}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1024,   39 }, 
}, 
{ 
{ {8, 8, 8, 13, 13, 13, 18, 18, 18}, {0, 5, 10, 0, 5, 10, 0, 5, 10}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,    2,   29 }, 
{ {10, 10, 10, 16, 16, 16, 22, 22, 22}, {0, 6, 12, 0, 6, 12, 0, 6, 12}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,    2,   29 }, 
{ {13, 13, 13, 21, 21, 21, 29, 29, 29}, {0, 8, 16, 0, 8, 16, 0, 8, 16}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,    2,   29 }, 
{ {17, 17, 17, 27, 27, 27, 37, 37, 37}, {0, 10, 20, 0, 10, 20, 0, 10, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,    2,   29 }, 
}, 
{ 
{ {2, 2, 2, 7, 7, 7, 12, 12, 12}, {20, 25, 30, 20, 25, 30, 20, 25, 30}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -605,   28 }, 
{ {2, 2, 2, 8, 8, 8, 14, 14, 14}, {26, 32, 38, 26, 32, 38, 26, 32, 38}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -605,   28 }, 
{ {3, 3, 3, 11, 11, 11, 19, 19, 19}, {32, 40, 48, 32, 40, 48, 32, 40, 48}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -605,   28 }, 
{ {4, 4, 4, 14, 14, 14, 24, 24, 24}, {40, 50, 60, 40, 50, 60, 40, 50, 60}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -605,   28 }, 
}, 
{ 
{ {2, 2, 2, 16, 16, 16, 30, 30, 30}, {0, 5, 10, 0, 5, 10, 0, 5, 10}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1552,   28 }, 
{ {2, 2, 2, 19, 19, 19, 36, 36, 36}, {0, 6, 12, 0, 6, 12, 0, 6, 12}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1552,   28 }, 
{ {3, 3, 3, 25, 25, 25, 47, 47, 47}, {0, 8, 16, 0, 8, 16, 0, 8, 16}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1552,   28 }, 
{ {4, 4, 4, 32, 32, 32, 60, 60, 60}, {0, 10, 20, 0, 10, 20, 0, 10, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1552,   28 }, 
}, 
{ 
{ {0, 0, 0, 5, 5, 5, 10, 10, 10}, {2, 7, 12, 2, 7, 12, 2, 7, 12}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -1030,   30 }, 
{ {0, 0, 0, 6, 6, 6, 12, 12, 12}, {2, 8, 14, 2, 8, 14, 2, 8, 14}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -1030,   30 }, 
{ {0, 0, 0, 8, 8, 8, 16, 16, 16}, {3, 11, 19, 3, 11, 19, 3, 11, 19}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -1030,   30 }, 
{ {0, 0, 0, 10, 10, 10, 20, 20, 20}, {4, 14, 24, 4, 14, 24, 4, 14, 24}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -1030,   30 }, 
}, 
{ 
{ {0, 0, 0, 5, 5, 5, 10, 10, 10}, {10, 15, 20, 10, 15, 20, 10, 15, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -102,   26 }, 
{ {0, 0, 0, 6, 6, 6, 12, 12, 12}, {13, 19, 25, 13, 19, 25, 13, 19, 25}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -102,   26 }, 
{ {0, 0, 0, 8, 8, 8, 16, 16, 16}, {17, 25, 33, 17, 25, 33, 17, 25, 33}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -102,   26 }, 
{ {0, 0, 0, 10, 10, 10, 20, 20, 20}, {22, 32, 42, 22, 32, 42, 22, 32, 42}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -102,   26 }, 
}, 
{ 
{ {14, 14, 14, 22, 22, 22, 30, 30, 30}, {19, 24, 29, 19, 24, 29, 19, 24, 29}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -732,   25 }, 
{ {18, 18, 18, 28, 28, 28, 38, 38, 38}, {24, 30, 36, 24, 30, 36, 24, 30, 36}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -732,   25 }, 
{ {23, 23, 23, 35, 35, 35, 47, 47, 47}, {31, 39, 47, 31, 39, 47, 31, 39, 47}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -732,   25 }, 
{ {29, 29, 29, 44, 44, 44, 59, 59, 59}, {39, 49, 59, 39, 49, 59, 39, 49, 59}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -732,   25 }, 
}, 
{ 
{ {20, 20, 20, 25, 25, 25, 30, 30, 30}, {12, 21, 30, 12, 21, 30, 12, 21, 30}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, 1669,   24 }, 
{ {26, 26, 26, 32, 32, 32, 38, 38, 38}, {16, 27, 38, 16, 27, 38, 16, 27, 38}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, 1669,   24 }, 
{ {32, 32, 32, 40, 40, 40, 48, 48, 48}, {20, 34, 48, 20, 34, 48, 20, 34, 48}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, 1669,   24 }, 
{ {40, 40, 40, 50, 50, 50, 60, 60, 60}, {24, 42, 60, 24, 42, 60, 24, 42, 60}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, 1669,   24 }, 
}, 
{ 
{ {8, 8, 8, 16, 16, 16, 24, 24, 24}, {15, 20, 25, 15, 20, 25, 15, 20, 25}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -774,   27 }, 
{ {10, 10, 10, 20, 20, 20, 30, 30, 30}, {20, 26, 32, 20, 26, 32, 20, 26, 32}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -774,   27 }, 
{ {13, 13, 13, 25, 25, 25, 37, 37, 37}, {25, 33, 41, 25, 33, 41, 25, 33, 41}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -774,   27 }, 
{ {17, 17, 17, 32, 32, 32, 47, 47, 47}, {32, 42, 52, 32, 42, 52, 32, 42, 52}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -774,   27 }, 
}, 
{ 
{ {0, 0, 4, 4, 8, 8, 12, 12, 0}, {2, 22, 2, 22, 2, 22, 2, 22, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1992,   27 }, 
{ {0, 0, 5, 5, 10, 10, 15, 15, 0}, {2, 27, 2, 27, 2, 27, 2, 27, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1992,   27 }, 
{ {0, 0, 6, 6, 12, 12, 18, 18, 0}, {3, 35, 3, 35, 3, 35, 3, 35, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1992,   27 }, 
{ {0, 0, 8, 8, 16, 16, 24, 24, 0}, {4, 44, 4, 44, 4, 44, 4, 44, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1992,   27 }, 
}, 
{ 
{ {9, 9, 9, 15, 15, 15, 21, 21, 21}, {15, 20, 25, 15, 20, 25, 15, 20, 25}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  644,   26 }, 
{ {12, 12, 12, 20, 20, 20, 28, 28, 28}, {20, 26, 32, 20, 26, 32, 20, 26, 32}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  644,   26 }, 
{ {15, 15, 15, 25, 25, 25, 35, 35, 35}, {25, 33, 41, 25, 33, 41, 25, 33, 41}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  644,   26 }, 
{ {19, 19, 19, 32, 32, 32, 45, 45, 45}, {32, 42, 52, 32, 42, 52, 32, 42, 52}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  644,   26 }, 
}, 
{ 
{ {0, 0, 0, 13, 13, 13, 0, 0, 0}, {20, 25, 30, 20, 25, 30, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  803,   25 }, 
{ {0, 0, 0, 16, 16, 16, 0, 0, 0}, {26, 32, 38, 26, 32, 38, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  803,   25 }, 
{ {0, 0, 0, 20, 20, 20, 0, 0, 0}, {32, 40, 48, 32, 40, 48, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  803,   25 }, 
{ {0, 0, 0, 25, 25, 25, 0, 0, 0}, {40, 50, 60, 40, 50, 60, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  803,   25 }, 
}, 
{ 
{ {2, 2, 2, 7, 7, 7, 12, 12, 12}, {12, 21, 30, 12, 21, 30, 12, 21, 30}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -1407,   24 }, 
{ {2, 2, 2, 8, 8, 8, 14, 14, 14}, {15, 26, 37, 15, 26, 37, 15, 26, 37}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -1407,   24 }, 
{ {3, 3, 3, 11, 11, 11, 19, 19, 19}, {19, 33, 47, 19, 33, 47, 19, 33, 47}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -1407,   24 }, 
{ {4, 4, 4, 14, 14, 14, 24, 24, 24}, {24, 42, 60, 24, 42, 60, 24, 42, 60}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -1407,   24 }, 
}, 
{ 
{ {5, 5, 9, 9, 13, 13, 17, 17, 0}, {8, 22, 8, 22, 8, 22, 8, 22, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  685,   23 }, 
{ {7, 7, 12, 12, 17, 17, 22, 22, 0}, {10, 27, 10, 27, 10, 27, 10, 27, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  685,   23 }, 
{ {9, 9, 15, 15, 21, 21, 27, 27, 0}, {13, 35, 13, 35, 13, 35, 13, 35, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  685,   23 }, 
{ {12, 12, 20, 20, 28, 28, 36, 36, 0}, {17, 45, 17, 45, 17, 45, 17, 45, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  685,   23 }, 
}, 
{ 
{ {7, 7, 7, 18, 18, 18, 0, 0, 0}, {8, 14, 20, 8, 14, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1,   -4,   22 }, 
{ {9, 9, 9, 23, 23, 23, 0, 0, 0}, {10, 18, 26, 10, 18, 26, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1,   -4,   22 }, 
{ {11, 11, 11, 29, 29, 29, 0, 0, 0}, {13, 23, 33, 13, 23, 33, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1,   -4,   22 }, 
{ {14, 14, 14, 37, 37, 37, 0, 0, 0}, {17, 30, 43, 17, 30, 43, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1,   -4,   22 }, 
}, 
{ 
{ {0, 0, 0, 10, 10, 10, 0, 0, 0}, {10, 15, 20, 10, 15, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,   40,   20 }, 
{ {0, 0, 0, 13, 13, 13, 0, 0, 0}, {13, 19, 25, 13, 19, 25, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,   40,   20 }, 
{ {0, 0, 0, 16, 16, 16, 0, 0, 0}, {17, 25, 33, 17, 25, 33, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,   40,   20 }, 
{ {0, 0, 0, 20, 20, 20, 0, 0, 0}, {22, 32, 42, 22, 32, 42, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,   40,   20 }, 
}, 
{ 
{ {15, 15, 19, 19, 23, 23, 27, 27, 0}, {0, 11, 0, 11, 0, 11, 0, 11, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -740,   19 }, 
{ {20, 20, 25, 25, 30, 30, 35, 35, 0}, {0, 14, 0, 14, 0, 14, 0, 14, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -740,   19 }, 
{ {25, 25, 31, 31, 37, 37, 43, 43, 0}, {0, 18, 0, 18, 0, 18, 0, 18, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -740,   19 }, 
{ {32, 32, 40, 40, 48, 48, 56, 56, 0}, {0, 23, 0, 23, 0, 23, 0, 23, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -740,   19 }, 
}, 
{ 
{ {8, 8, 8, 21, 21, 21, 0, 0, 0}, {18, 23, 28, 18, 23, 28, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1,  688,   13 }, 
{ {10, 10, 10, 26, 26, 26, 0, 0, 0}, {23, 29, 35, 23, 29, 35, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1,  688,   13 }, 
{ {13, 13, 13, 33, 33, 33, 0, 0, 0}, {29, 37, 45, 29, 37, 45, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1,  688,   13 }, 
{ {17, 17, 17, 42, 42, 42, 0, 0, 0}, {37, 47, 57, 37, 47, 57, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1,  688,   13 }, 
}, 
{ 
{ {9, 9, 18, 18, 27, 27, 0, 0, 0}, {0, 29, 0, 29, 0, 29, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 6498,   23 }, 
{ {12, 12, 23, 23, 34, 34, 0, 0, 0}, {0, 36, 0, 36, 0, 36, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 6498,   23 }, 
{ {15, 15, 29, 29, 43, 43, 0, 0, 0}, {0, 46, 0, 46, 0, 46, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 6498,   23 }, 
{ {19, 19, 37, 37, 55, 55, 0, 0, 0}, {0, 58, 0, 58, 0, 58, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 6498,   23 }, 
}, 
{ 
{ {10, 10, 19, 19, 28, 28, 0, 0, 0}, {13, 23, 13, 23, 13, 23, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -348,   22 }, 
{ {13, 13, 24, 24, 35, 35, 0, 0, 0}, {16, 29, 16, 29, 16, 29, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -348,   22 }, 
{ {17, 17, 31, 31, 45, 45, 0, 0, 0}, {21, 37, 21, 37, 21, 37, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -348,   22 }, 
{ {22, 22, 40, 40, 58, 58, 0, 0, 0}, {27, 47, 27, 47, 27, 47, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -348,   22 }, 
}, 
{ 
{ {12, 12, 12, 25, 25, 25, 0, 0, 0}, {3, 8, 13, 3, 8, 13, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, 1261,   20 }, 
{ {15, 15, 15, 31, 31, 31, 0, 0, 0}, {4, 10, 16, 4, 10, 16, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, 1261,   20 }, 
{ {19, 19, 19, 39, 39, 39, 0, 0, 0}, {5, 13, 21, 5, 13, 21, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, 1261,   20 }, 
{ {24, 24, 24, 49, 49, 49, 0, 0, 0}, {7, 17, 27, 7, 17, 27, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, 1261,   20 }, 
}, 
{ 
{ {0, 0, 0, 30, 30, 30, 0, 0, 0}, {4, 10, 16, 4, 10, 16, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -6031,   20 }, 
{ {0, 0, 0, 38, 38, 38, 0, 0, 0}, {5, 13, 21, 5, 13, 21, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -6031,   20 }, 
{ {0, 0, 0, 48, 48, 48, 0, 0, 0}, {7, 17, 27, 7, 17, 27, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -6031,   20 }, 
{ {0, 0, 0, 60, 60, 60, 0, 0, 0}, {9, 22, 35, 9, 22, 35, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -6031,   20 }, 
}, 
{ 
{ {12, 12, 12, 17, 17, 17, 22, 22, 22}, {17, 22, 27, 17, 22, 27, 17, 22, 27}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -638,   20 }, 
{ {15, 15, 15, 21, 21, 21, 27, 27, 27}, {21, 27, 33, 21, 27, 33, 21, 27, 33}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -638,   20 }, 
{ {19, 19, 19, 27, 27, 27, 35, 35, 35}, {27, 35, 43, 27, 35, 43, 27, 35, 43}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -638,   20 }, 
{ {24, 24, 24, 34, 34, 34, 44, 44, 44}, {34, 44, 54, 34, 44, 54, 34, 44, 54}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -638,   20 }, 
}, 
{ 
{ {10, 10, 10, 20, 20, 20, 0, 0, 0}, {10, 20, 30, 10, 20, 30, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,   63,   16 }, 
{ {13, 13, 13, 26, 26, 26, 0, 0, 0}, {12, 25, 38, 12, 25, 38, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,   63,   16 }, 
{ {17, 17, 17, 33, 33, 33, 0, 0, 0}, {16, 32, 48, 16, 32, 48, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,   63,   16 }, 
{ {22, 22, 22, 42, 42, 42, 0, 0, 0}, {20, 40, 60, 20, 40, 60, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,   63,   16 }, 
}, 
{ 
{ {5, 5, 13, 13, 21, 21, 0, 0, 0}, {19, 30, 19, 30, 19, 30, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -1903,   21 }, 
{ {7, 7, 17, 17, 27, 27, 0, 0, 0}, {24, 38, 24, 38, 24, 38, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -1903,   21 }, 
{ {9, 9, 21, 21, 33, 33, 0, 0, 0}, {30, 48, 30, 48, 30, 48, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -1903,   21 }, 
{ {12, 12, 27, 27, 42, 42, 0, 0, 0}, {37, 60, 37, 60, 37, 60, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -1903,   21 }, 
}, 
{ 
{ {8, 8, 17, 17, 26, 26, 0, 0, 0}, {5, 28, 5, 28, 5, 28, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 2095,   20 }, 
{ {10, 10, 21, 21, 32, 32, 0, 0, 0}, {7, 36, 7, 36, 7, 36, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 2095,   20 }, 
{ {13, 13, 27, 27, 41, 41, 0, 0, 0}, {9, 45, 9, 45, 9, 45, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 2095,   20 }, 
{ {17, 17, 35, 35, 53, 53, 0, 0, 0}, {12, 57, 12, 57, 12, 57, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 2095,   20 }, 
}, 
{ 
{ {0, 0, 10, 10, 20, 20, 30, 30, 0}, {0, 26, 0, 26, 0, 26, 0, 26, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -15214,   21 }, 
{ {12, 12, 25, 25, 38, 38, 0, 0, 0}, {0, 33, 0, 33, 0, 33, 0, 0, 0}, {-3, 3, 3, -3, -1, 1, 0, 0, 0}, -1, -15214,   21 }, 
{ {0, 0, 16, 16, 32, 32, 48, 48, 0}, {0, 42, 0, 42, 0, 42, 0, 42, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -15214,   21 }, 
{ {0, 0, 20, 20, 40, 40, 60, 60, 0}, {0, 53, 0, 53, 0, 53, 0, 53, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -15214,   21 }, 
}, 
{ 
{ {2, 2, 11, 11, 20, 20, 0, 0, 0}, {0, 15, 0, 15, 0, 15, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -6383,   23 }, 
{ {2, 2, 13, 13, 24, 24, 0, 0, 0}, {0, 19, 0, 19, 0, 19, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -6383,   23 }, 
{ {3, 3, 17, 17, 31, 31, 0, 0, 0}, {0, 24, 0, 24, 0, 24, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -6383,   23 }, 
{ {4, 4, 22, 22, 40, 40, 0, 0, 0}, {0, 30, 0, 30, 0, 30, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -6383,   23 }, 
}, 
{ 
{ {10, 10, 10, 15, 15, 15, 20, 20, 20}, {18, 23, 28, 18, 23, 28, 18, 23, 28}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  703,   19 }, 
{ {13, 13, 13, 19, 19, 19, 25, 25, 25}, {23, 29, 35, 23, 29, 35, 23, 29, 35}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  703,   19 }, 
{ {17, 17, 17, 25, 25, 25, 33, 33, 33}, {29, 37, 45, 29, 37, 45, 29, 37, 45}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  703,   19 }, 
{ {22, 22, 22, 32, 32, 32, 42, 42, 42}, {37, 47, 57, 37, 47, 57, 37, 47, 57}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  703,   19 }, 
}, 
{ 
{ {7, 7, 12, 12, 17, 17, 0, 0, 0}, {5, 19, 5, 19, 5, 19, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -2160,   12 }, 
{ {9, 9, 15, 15, 21, 21, 0, 0, 0}, {7, 24, 7, 24, 7, 24, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -2160,   12 }, 
{ {11, 11, 19, 19, 27, 27, 0, 0, 0}, {9, 31, 9, 31, 9, 31, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -2160,   12 }, 
{ {14, 14, 24, 24, 34, 34, 0, 0, 0}, {12, 40, 12, 40, 12, 40, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -2160,   12 }, 
}, 
{ 
{ {13, 13, 18, 18, 23, 23, 28, 28, 0}, {10, 20, 10, 20, 10, 20, 10, 20, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -914,   20 }, 
{ {16, 16, 22, 22, 28, 28, 34, 34, 0}, {13, 26, 13, 26, 13, 26, 13, 26, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -914,   20 }, 
{ {21, 21, 29, 29, 37, 37, 45, 45, 0}, {17, 33, 17, 33, 17, 33, 17, 33, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -914,   20 }, 
{ {27, 27, 37, 37, 47, 47, 57, 57, 0}, {22, 42, 22, 42, 22, 42, 22, 42, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -914,   20 }, 
}, 
{ 
{ {9, 9, 13, 13, 17, 17, 21, 21, 0}, {7, 23, 7, 23, 7, 23, 7, 23, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1363,   22 }, 
{ {12, 12, 17, 17, 22, 22, 27, 27, 0}, {9, 30, 9, 30, 9, 30, 9, 30, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1363,   22 }, 
{ {15, 15, 21, 21, 27, 27, 33, 33, 0}, {11, 37, 11, 37, 11, 37, 11, 37, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1363,   22 }, 
{ {19, 19, 27, 27, 35, 35, 43, 43, 0}, {14, 47, 14, 47, 14, 47, 14, 47, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1363,   22 }, 
}, 
{ 
{ {20, 20, 25, 25, 30, 30, 0, 0, 0}, {0, 30, 0, 30, 0, 30, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3237,   58 }, 
{ {26, 26, 32, 32, 38, 38, 0, 0, 0}, {0, 38, 0, 38, 0, 38, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3237,   58 }, 
{ {32, 32, 40, 40, 48, 48, 0, 0, 0}, {0, 48, 0, 48, 0, 48, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3237,   58 }, 
{ {40, 40, 50, 50, 60, 60, 0, 0, 0}, {0, 60, 0, 60, 0, 60, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3237,   58 }, 
}, 
{ 
{ {0, 0, 0, 14, 14, 14, 0, 0, 0}, {14, 19, 24, 14, 19, 24, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 2857,   33 }, 
{ {0, 0, 0, 17, 17, 17, 0, 0, 0}, {18, 24, 30, 18, 24, 30, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 2857,   33 }, 
{ {0, 0, 0, 22, 22, 22, 0, 0, 0}, {23, 31, 39, 23, 31, 39, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 2857,   33 }, 
{ {0, 0, 0, 28, 28, 28, 0, 0, 0}, {29, 39, 49, 29, 39, 49, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 2857,   33 }, 
}, 
{ 
{ {18, 18, 22, 22, 26, 26, 30, 30, 0}, {0, 23, 0, 23, 0, 23, 0, 23, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -2208,   26 }, 
{ {23, 23, 28, 28, 33, 33, 38, 38, 0}, {0, 29, 0, 29, 0, 29, 0, 29, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -2208,   26 }, 
{ {30, 30, 36, 36, 42, 42, 48, 48, 0}, {0, 36, 0, 36, 0, 36, 0, 36, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -2208,   26 }, 
{ {36, 36, 44, 44, 52, 52, 60, 60, 0}, {0, 45, 0, 45, 0, 45, 0, 45, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -2208,   26 }, 
}, 
{ 
{ {7, 7, 12, 12, 17, 17, 0, 0, 0}, {7, 20, 7, 20, 7, 20, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -2163,   24 }, 
{ {9, 9, 15, 15, 21, 21, 0, 0, 0}, {9, 25, 9, 25, 9, 25, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -2163,   24 }, 
{ {11, 11, 19, 19, 27, 27, 0, 0, 0}, {11, 31, 11, 31, 11, 31, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -2163,   24 }, 
{ {14, 14, 24, 24, 34, 34, 0, 0, 0}, {14, 39, 14, 39, 14, 39, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -2163,   24 }, 
}, 
{ 
{ {10, 10, 20, 20, 30, 30, 0, 0, 0}, {18, 29, 18, 29, 18, 29, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 4078,   26 }, 
{ {12, 12, 25, 25, 38, 38, 0, 0, 0}, {23, 37, 23, 37, 23, 37, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 4078,   26 }, 
{ {16, 16, 32, 32, 48, 48, 0, 0, 0}, {29, 47, 29, 47, 29, 47, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 4078,   26 }, 
{ {20, 20, 40, 40, 60, 60, 0, 0, 0}, {37, 60, 37, 60, 37, 60, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 4078,   26 }, 
}, 
{ 
{ {17, 17, 17, 22, 22, 22, 27, 27, 27}, {13, 18, 23, 13, 18, 23, 13, 18, 23}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -397,   21 }, 
{ {21, 21, 21, 27, 27, 27, 33, 33, 33}, {16, 22, 28, 16, 22, 28, 16, 22, 28}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -397,   21 }, 
{ {27, 27, 27, 35, 35, 35, 43, 43, 43}, {21, 29, 37, 21, 29, 37, 21, 29, 37}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -397,   21 }, 
{ {34, 34, 34, 44, 44, 44, 54, 54, 54}, {27, 37, 47, 27, 37, 47, 27, 37, 47}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -397,   21 }, 
}, 
{ 
{ {2, 2, 12, 12, 22, 22, 0, 0, 0}, {18, 28, 18, 28, 18, 28, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3595,   22 }, 
{ {2, 2, 15, 15, 28, 28, 0, 0, 0}, {23, 36, 23, 36, 23, 36, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3595,   22 }, 
{ {3, 3, 19, 19, 35, 35, 0, 0, 0}, {29, 45, 29, 45, 29, 45, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3595,   22 }, 
{ {4, 4, 24, 24, 44, 44, 0, 0, 0}, {37, 57, 37, 57, 37, 57, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3595,   22 }, 
}, 
{ 
{ {9, 9, 9, 15, 15, 15, 21, 21, 21}, {13, 19, 25, 13, 19, 25, 13, 19, 25}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -500,   21 }, 
{ {12, 12, 12, 20, 20, 20, 28, 28, 28}, {16, 24, 32, 16, 24, 32, 16, 24, 32}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -500,   21 }, 
{ {15, 15, 15, 25, 25, 25, 35, 35, 35}, {21, 31, 41, 21, 31, 41, 21, 31, 41}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -500,   21 }, 
{ {19, 19, 19, 32, 32, 32, 45, 45, 45}, {27, 40, 53, 27, 40, 53, 27, 40, 53}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -500,   21 }, 
}, 
{ 
{ {0, 0, 10, 10, 20, 20, 30, 30, 0}, {0, 30, 0, 30, 0, 30, 0, 30, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -16516,   20 }, 
{ {12, 12, 25, 25, 38, 38, 0, 0, 0}, {0, 38, 0, 38, 0, 38, 0, 0, 0}, {-3, 3, 3, -3, -1, 1, 0, 0, 0}, -1, -16516,   20 }, 
{ {0, 0, 16, 16, 32, 32, 48, 48, 0}, {0, 48, 0, 48, 0, 48, 0, 48, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -16516,   20 }, 
{ {0, 0, 20, 20, 40, 40, 60, 60, 0}, {0, 60, 0, 60, 0, 60, 0, 60, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -16516,   20 }, 
}, 
{ 
{ {19, 19, 24, 24, 29, 29, 0, 0, 0}, {2, 22, 2, 22, 2, 22, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 4669,   25 }, 
{ {24, 24, 30, 30, 36, 36, 0, 0, 0}, {2, 27, 2, 27, 2, 27, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 4669,   25 }, 
{ {31, 31, 39, 39, 47, 47, 0, 0, 0}, {3, 35, 3, 35, 3, 35, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 4669,   25 }, 
{ {39, 39, 49, 49, 59, 59, 0, 0, 0}, {4, 44, 4, 44, 4, 44, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 4669,   25 }, 
}, 
{ 
{ {13, 13, 17, 17, 21, 21, 25, 25, 0}, {0, 10, 0, 10, 0, 10, 0, 10, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -1285,   20 }, 
{ {16, 16, 21, 21, 26, 26, 31, 31, 0}, {0, 13, 0, 13, 0, 13, 0, 13, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -1285,   20 }, 
{ {21, 21, 27, 27, 33, 33, 39, 39, 0}, {0, 16, 0, 16, 0, 16, 0, 16, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -1285,   20 }, 
{ {27, 27, 35, 35, 43, 43, 51, 51, 0}, {0, 20, 0, 20, 0, 20, 0, 20, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -1285,   20 }, 
}, 
{ 
{ {20, 20, 20, 25, 25, 25, 30, 30, 30}, {10, 15, 20, 10, 15, 20, 10, 15, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  132,   18 }, 
{ {26, 26, 26, 32, 32, 32, 38, 38, 38}, {13, 19, 25, 13, 19, 25, 13, 19, 25}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  132,   18 }, 
{ {32, 32, 32, 40, 40, 40, 48, 48, 48}, {17, 25, 33, 17, 25, 33, 17, 25, 33}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  132,   18 }, 
{ {40, 40, 40, 50, 50, 50, 60, 60, 60}, {22, 32, 42, 22, 32, 42, 22, 32, 42}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  132,   18 }, 
}, 
{ 
{ {19, 19, 19, 24, 24, 24, 29, 29, 29}, {9, 14, 19, 9, 14, 19, 9, 14, 19}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  -14,   18 }, 
{ {24, 24, 24, 30, 30, 30, 36, 36, 36}, {12, 18, 24, 12, 18, 24, 12, 18, 24}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  -14,   18 }, 
{ {31, 31, 31, 39, 39, 39, 47, 47, 47}, {15, 23, 31, 15, 23, 31, 15, 23, 31}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  -14,   18 }, 
{ {39, 39, 39, 49, 49, 49, 59, 59, 59}, {19, 29, 39, 19, 29, 39, 19, 29, 39}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  -14,   18 }, 
}, 
{ 
{ {2, 2, 2, 12, 12, 12, 22, 22, 22}, {0, 15, 30, 0, 15, 30, 0, 15, 30}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -3943,   19 }, 
{ {2, 2, 2, 15, 15, 15, 28, 28, 28}, {0, 19, 38, 0, 19, 38, 0, 19, 38}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -3943,   19 }, 
{ {3, 3, 3, 19, 19, 19, 35, 35, 35}, {0, 24, 48, 0, 24, 48, 0, 24, 48}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -3943,   19 }, 
{ {4, 4, 4, 24, 24, 24, 44, 44, 44}, {0, 30, 60, 0, 30, 60, 0, 30, 60}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -3943,   19 }, 
}, 
{ 
{ {2, 2, 2, 7, 7, 7, 12, 12, 12}, {9, 18, 27, 9, 18, 27, 9, 18, 27}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  256,   20 }, 
{ {2, 2, 2, 8, 8, 8, 14, 14, 14}, {12, 23, 34, 12, 23, 34, 12, 23, 34}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  256,   20 }, 
{ {3, 3, 3, 11, 11, 11, 19, 19, 19}, {15, 29, 43, 15, 29, 43, 15, 29, 43}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  256,   20 }, 
{ {4, 4, 4, 14, 14, 14, 24, 24, 24}, {19, 37, 55, 19, 37, 55, 19, 37, 55}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  256,   20 }, 
}, 
{ 
{ {0, 0, 4, 4, 8, 8, 12, 12, 0}, {15, 29, 15, 29, 15, 29, 15, 29, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  880,   18 }, 
{ {0, 0, 5, 5, 10, 10, 15, 15, 0}, {20, 37, 20, 37, 20, 37, 20, 37, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  880,   18 }, 
{ {0, 0, 6, 6, 12, 12, 18, 18, 0}, {25, 47, 25, 47, 25, 47, 25, 47, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  880,   18 }, 
{ {0, 0, 8, 8, 16, 16, 24, 24, 0}, {32, 60, 32, 60, 32, 60, 32, 60, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  880,   18 }, 
}, 
{ 
{ {8, 8, 8, 13, 13, 13, 18, 18, 18}, {0, 14, 28, 0, 14, 28, 0, 14, 28}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -3443,   18 }, 
{ {10, 10, 10, 16, 16, 16, 22, 22, 22}, {0, 17, 34, 0, 17, 34, 0, 17, 34}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -3443,   18 }, 
{ {13, 13, 13, 21, 21, 21, 29, 29, 29}, {0, 22, 44, 0, 22, 44, 0, 22, 44}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -3443,   18 }, 
{ {17, 17, 17, 27, 27, 27, 37, 37, 37}, {0, 28, 56, 0, 28, 56, 0, 28, 56}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -3443,   18 }, 
}, 
{ 
{ {14, 14, 22, 22, 30, 30, 0, 0, 0}, {0, 11, 0, 11, 0, 11, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 4031,   17 }, 
{ {18, 18, 28, 28, 38, 38, 0, 0, 0}, {0, 14, 0, 14, 0, 14, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 4031,   17 }, 
{ {23, 23, 35, 35, 47, 47, 0, 0, 0}, {0, 18, 0, 18, 0, 18, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 4031,   17 }, 
{ {29, 29, 44, 44, 59, 59, 0, 0, 0}, {0, 23, 0, 23, 0, 23, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 4031,   17 }, 
}, 
{ 
{ {18, 18, 18, 24, 24, 24, 30, 30, 30}, {18, 23, 28, 18, 23, 28, 18, 23, 28}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -290,   17 }, 
{ {22, 22, 22, 30, 30, 30, 38, 38, 38}, {23, 29, 35, 23, 29, 35, 23, 29, 35}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -290,   17 }, 
{ {28, 28, 28, 38, 38, 38, 48, 48, 48}, {29, 37, 45, 29, 37, 45, 29, 37, 45}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -290,   17 }, 
{ {34, 34, 34, 47, 47, 47, 60, 60, 60}, {37, 47, 57, 37, 47, 57, 37, 47, 57}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -290,   17 }, 
}, 
{ 
{ {18, 18, 18, 23, 23, 23, 28, 28, 28}, {18, 24, 30, 18, 24, 30, 18, 24, 30}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  288,   20 }, 
{ {23, 23, 23, 29, 29, 29, 35, 35, 35}, {22, 30, 38, 22, 30, 38, 22, 30, 38}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  288,   20 }, 
{ {29, 29, 29, 37, 37, 37, 45, 45, 45}, {28, 38, 48, 28, 38, 48, 28, 38, 48}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  288,   20 }, 
{ {37, 37, 37, 47, 47, 47, 57, 57, 57}, {34, 47, 60, 34, 47, 60, 34, 47, 60}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  288,   20 }, 
}, 
{ 
{ {5, 5, 9, 9, 13, 13, 17, 17, 0}, {2, 12, 2, 12, 2, 12, 2, 12, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -636,   21 }, 
{ {7, 7, 12, 12, 17, 17, 22, 22, 0}, {2, 15, 2, 15, 2, 15, 2, 15, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -636,   21 }, 
{ {9, 9, 15, 15, 21, 21, 27, 27, 0}, {3, 19, 3, 19, 3, 19, 3, 19, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -636,   21 }, 
{ {12, 12, 20, 20, 28, 28, 36, 36, 0}, {4, 24, 4, 24, 4, 24, 4, 24, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -636,   21 }, 
}, 
{ 
{ {4, 4, 12, 12, 20, 20, 28, 28, 0}, {15, 25, 15, 25, 15, 25, 15, 25, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  222,   16 }, 
{ {5, 5, 15, 15, 25, 25, 35, 35, 0}, {20, 33, 20, 33, 20, 33, 20, 33, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  222,   16 }, 
{ {7, 7, 19, 19, 31, 31, 43, 43, 0}, {25, 41, 25, 41, 25, 41, 25, 41, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  222,   16 }, 
{ {9, 9, 24, 24, 39, 39, 54, 54, 0}, {32, 52, 32, 52, 32, 52, 32, 52, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  222,   16 }, 
}, 
{ 
{ {20, 20, 20, 30, 30, 30, 0, 0, 0}, {10, 15, 20, 10, 15, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,   97,   16 }, 
{ {25, 25, 25, 38, 38, 38, 0, 0, 0}, {13, 19, 25, 13, 19, 25, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,   97,   16 }, 
{ {32, 32, 32, 48, 48, 48, 0, 0, 0}, {17, 25, 33, 17, 25, 33, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,   97,   16 }, 
{ {40, 40, 40, 60, 60, 60, 0, 0, 0}, {22, 32, 42, 22, 32, 42, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,   97,   16 }, 
}, 
{ 
{ {0, 0, 14, 14, 28, 28, 0, 0, 0}, {3, 23, 3, 23, 3, 23, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -6247,   17 }, 
{ {0, 0, 17, 17, 34, 34, 0, 0, 0}, {4, 29, 4, 29, 4, 29, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -6247,   17 }, 
{ {0, 0, 22, 22, 44, 44, 0, 0, 0}, {5, 37, 5, 37, 5, 37, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -6247,   17 }, 
{ {0, 0, 28, 28, 56, 56, 0, 0, 0}, {7, 47, 7, 47, 7, 47, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -6247,   17 }, 
}, 
{ 
{ {9, 9, 17, 17, 25, 25, 0, 0, 0}, {2, 15, 2, 15, 2, 15, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -573,   17 }, 
{ {12, 12, 22, 22, 32, 32, 0, 0, 0}, {2, 18, 2, 18, 2, 18, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -573,   17 }, 
{ {15, 15, 27, 27, 39, 39, 0, 0, 0}, {3, 23, 3, 23, 3, 23, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -573,   17 }, 
{ {19, 19, 34, 34, 49, 49, 0, 0, 0}, {4, 29, 4, 29, 4, 29, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -573,   17 }, 
}, 
{ 
{ {0, 0, 0, 29, 29, 29, 0, 0, 0}, {7, 15, 23, 7, 15, 23, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -2996,   17 }, 
{ {0, 0, 0, 36, 36, 36, 0, 0, 0}, {9, 19, 29, 9, 19, 29, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -2996,   17 }, 
{ {0, 0, 0, 46, 46, 46, 0, 0, 0}, {11, 23, 35, 11, 23, 35, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -2996,   17 }, 
{ {0, 0, 0, 58, 58, 58, 0, 0, 0}, {14, 29, 44, 14, 29, 44, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -2996,   17 }, 
}, 
{ 
{ {3, 3, 7, 7, 11, 11, 15, 15, 0}, {0, 25, 0, 25, 0, 25, 0, 25, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -1277,   15 }, 
{ {4, 4, 9, 9, 14, 14, 19, 19, 0}, {0, 32, 0, 32, 0, 32, 0, 32, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -1277,   15 }, 
{ {5, 5, 11, 11, 17, 17, 23, 23, 0}, {0, 40, 0, 40, 0, 40, 0, 40, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -1277,   15 }, 
{ {7, 7, 15, 15, 23, 23, 31, 31, 0}, {0, 50, 0, 50, 0, 50, 0, 50, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -1277,   15 }, 
}, 
{ 
{ {4, 4, 8, 8, 12, 12, 16, 16, 0}, {7, 20, 7, 20, 7, 20, 7, 20, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -458,   18 }, 
{ {5, 5, 10, 10, 15, 15, 20, 20, 0}, {9, 25, 9, 25, 9, 25, 9, 25, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -458,   18 }, 
{ {7, 7, 13, 13, 19, 19, 25, 25, 0}, {11, 31, 11, 31, 11, 31, 11, 31, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -458,   18 }, 
{ {9, 9, 17, 17, 25, 25, 33, 33, 0}, {14, 39, 14, 39, 14, 39, 14, 39, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -458,   18 }, 
}, 
{ 
{ {5, 5, 5, 16, 16, 16, 27, 27, 27}, {7, 13, 19, 7, 13, 19, 7, 13, 19}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1399,   16 }, 
{ {7, 7, 7, 21, 21, 21, 35, 35, 35}, {9, 17, 25, 9, 17, 25, 9, 17, 25}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1399,   16 }, 
{ {9, 9, 9, 27, 27, 27, 45, 45, 45}, {11, 21, 31, 11, 21, 31, 11, 21, 31}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1399,   16 }, 
{ {12, 12, 12, 35, 35, 35, 58, 58, 58}, {14, 27, 40, 14, 27, 40, 14, 27, 40}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1399,   16 }, 
}, 
{ 
{ {20, 20, 20, 30, 30, 30, 0, 0, 0}, {20, 25, 30, 20, 25, 30, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  178,   15 }, 
{ {25, 25, 25, 38, 38, 38, 0, 0, 0}, {26, 32, 38, 26, 32, 38, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  178,   15 }, 
{ {32, 32, 32, 48, 48, 48, 0, 0, 0}, {32, 40, 48, 32, 40, 48, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  178,   15 }, 
{ {40, 40, 40, 60, 60, 60, 0, 0, 0}, {40, 50, 60, 40, 50, 60, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  178,   15 }, 
}, 
{ 
{ {4, 4, 4, 14, 14, 14, 24, 24, 24}, {9, 14, 19, 9, 14, 19, 9, 14, 19}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -895,   13 }, 
{ {5, 5, 5, 18, 18, 18, 31, 31, 31}, {12, 18, 24, 12, 18, 24, 12, 18, 24}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -895,   13 }, 
{ {7, 7, 7, 23, 23, 23, 39, 39, 39}, {15, 23, 31, 15, 23, 31, 15, 23, 31}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -895,   13 }, 
{ {9, 9, 9, 29, 29, 29, 49, 49, 49}, {19, 29, 39, 19, 29, 39, 19, 29, 39}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -895,   13 }, 
}, 
{ 
{ {2, 2, 2, 8, 8, 8, 14, 14, 14}, {17, 23, 29, 17, 23, 29, 17, 23, 29}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  656,   17 }, 
{ {2, 2, 2, 10, 10, 10, 18, 18, 18}, {21, 29, 37, 21, 29, 37, 21, 29, 37}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  656,   17 }, 
{ {3, 3, 3, 13, 13, 13, 23, 23, 23}, {27, 37, 47, 27, 37, 47, 27, 37, 47}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  656,   17 }, 
{ {4, 4, 4, 17, 17, 17, 30, 30, 30}, {34, 47, 60, 34, 47, 60, 34, 47, 60}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  656,   17 }, 
}, 
{ 
{ {13, 13, 13, 18, 18, 18, 23, 23, 23}, {14, 19, 24, 14, 19, 24, 14, 19, 24}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  173,   12 }, 
{ {16, 16, 16, 22, 22, 22, 28, 28, 28}, {18, 24, 30, 18, 24, 30, 18, 24, 30}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  173,   12 }, 
{ {21, 21, 21, 29, 29, 29, 37, 37, 37}, {23, 31, 39, 23, 31, 39, 23, 31, 39}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  173,   12 }, 
{ {27, 27, 27, 37, 37, 37, 47, 47, 47}, {29, 39, 49, 29, 39, 49, 29, 39, 49}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  173,   12 }, 
}, 
{ 
{ {2, 2, 2, 7, 7, 7, 12, 12, 12}, {14, 22, 30, 14, 22, 30, 14, 22, 30}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -1240,   20 }, 
{ {2, 2, 2, 8, 8, 8, 14, 14, 14}, {18, 28, 38, 18, 28, 38, 18, 28, 38}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -1240,   20 }, 
{ {3, 3, 3, 11, 11, 11, 19, 19, 19}, {24, 36, 48, 24, 36, 48, 24, 36, 48}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -1240,   20 }, 
{ {4, 4, 4, 14, 14, 14, 24, 24, 24}, {30, 45, 60, 30, 45, 60, 30, 45, 60}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -1240,   20 }, 
}, 
{ 
{ {0, 0, 0, 6, 6, 6, 12, 12, 12}, {19, 24, 29, 19, 24, 29, 19, 24, 29}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,   20,   15 }, 
{ {0, 0, 0, 8, 8, 8, 16, 16, 16}, {24, 30, 36, 24, 30, 36, 24, 30, 36}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,   20,   15 }, 
{ {0, 0, 0, 10, 10, 10, 20, 20, 20}, {31, 39, 47, 31, 39, 47, 31, 39, 47}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,   20,   15 }, 
{ {0, 0, 0, 13, 13, 13, 26, 26, 26}, {39, 49, 59, 39, 49, 59, 39, 49, 59}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,   20,   15 }, 
}, 
{ 
{ {12, 12, 12, 23, 23, 23, 0, 0, 0}, {15, 20, 25, 15, 20, 25, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  510,   13 }, 
{ {15, 15, 15, 29, 29, 29, 0, 0, 0}, {20, 26, 32, 20, 26, 32, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  510,   13 }, 
{ {19, 19, 19, 37, 37, 37, 0, 0, 0}, {25, 33, 41, 25, 33, 41, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  510,   13 }, 
{ {24, 24, 24, 47, 47, 47, 0, 0, 0}, {32, 42, 52, 32, 42, 52, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  510,   13 }, 
}, 
{ 
{ {15, 15, 15, 25, 25, 25, 0, 0, 0}, {15, 21, 27, 15, 21, 27, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 1098,   15 }, 
{ {20, 20, 20, 33, 33, 33, 0, 0, 0}, {20, 28, 36, 20, 28, 36, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 1098,   15 }, 
{ {25, 25, 25, 41, 41, 41, 0, 0, 0}, {25, 35, 45, 25, 35, 45, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 1098,   15 }, 
{ {32, 32, 32, 52, 52, 52, 0, 0, 0}, {32, 45, 58, 32, 45, 58, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 1098,   15 }, 
}, 
{ 
{ {15, 15, 15, 20, 20, 20, 25, 25, 25}, {3, 8, 13, 3, 8, 13, 3, 8, 13}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1395,   11 }, 
{ {20, 20, 20, 26, 26, 26, 32, 32, 32}, {4, 10, 16, 4, 10, 16, 4, 10, 16}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1395,   11 }, 
{ {25, 25, 25, 33, 33, 33, 41, 41, 41}, {5, 13, 21, 5, 13, 21, 5, 13, 21}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1395,   11 }, 
{ {32, 32, 32, 42, 42, 42, 52, 52, 52}, {7, 17, 27, 7, 17, 27, 7, 17, 27}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1395,   11 }, 
}, 
{ 
{ {2, 2, 6, 6, 10, 10, 14, 14, 0}, {20, 30, 20, 30, 20, 30, 20, 30, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -297,   17 }, 
{ {2, 2, 7, 7, 12, 12, 17, 17, 0}, {25, 38, 25, 38, 25, 38, 25, 38, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -297,   17 }, 
{ {3, 3, 9, 9, 15, 15, 21, 21, 0}, {32, 48, 32, 48, 32, 48, 32, 48, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -297,   17 }, 
{ {4, 4, 12, 12, 20, 20, 28, 28, 0}, {40, 60, 40, 60, 40, 60, 40, 60, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -297,   17 }, 
}, 
{ 
{ {5, 5, 10, 10, 15, 15, 0, 0, 0}, {10, 21, 10, 21, 10, 21, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, 1458,   10 }, 
{ {7, 7, 13, 13, 19, 19, 0, 0, 0}, {13, 27, 13, 27, 13, 27, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, 1458,   10 }, 
{ {9, 9, 17, 17, 25, 25, 0, 0, 0}, {17, 35, 17, 35, 17, 35, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, 1458,   10 }, 
{ {12, 12, 22, 22, 32, 32, 0, 0, 0}, {22, 45, 22, 45, 22, 45, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, 1458,   10 }, 
}, 
{ 
{ {0, 0, 0, 8, 8, 8, 16, 16, 16}, {20, 25, 30, 20, 25, 30, 20, 25, 30}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -523,   21 }, 
{ {0, 0, 0, 10, 10, 10, 20, 20, 20}, {26, 32, 38, 26, 32, 38, 26, 32, 38}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -523,   21 }, 
{ {0, 0, 0, 12, 12, 12, 24, 24, 24}, {32, 40, 48, 32, 40, 48, 32, 40, 48}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -523,   21 }, 
{ {0, 0, 0, 15, 15, 15, 30, 30, 30}, {40, 50, 60, 40, 50, 60, 40, 50, 60}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -523,   21 }, 
}, 
{ 
{ {0, 0, 5, 5, 10, 10, 15, 15, 0}, {19, 30, 19, 30, 19, 30, 19, 30, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  551,   15 }, 
{ {0, 0, 6, 6, 12, 12, 18, 18, 0}, {24, 38, 24, 38, 24, 38, 24, 38, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  551,   15 }, 
{ {0, 0, 8, 8, 16, 16, 24, 24, 0}, {30, 48, 30, 48, 30, 48, 30, 48, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  551,   15 }, 
{ {0, 0, 10, 10, 20, 20, 30, 30, 0}, {37, 60, 37, 60, 37, 60, 37, 60, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  551,   15 }, 
}, 
{ 
{ {9, 9, 9, 14, 14, 14, 19, 19, 19}, {17, 22, 27, 17, 22, 27, 17, 22, 27}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  574,   11 }, 
{ {12, 12, 12, 18, 18, 18, 24, 24, 24}, {21, 27, 33, 21, 27, 33, 21, 27, 33}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  574,   11 }, 
{ {15, 15, 15, 23, 23, 23, 31, 31, 31}, {27, 35, 43, 27, 35, 43, 27, 35, 43}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  574,   11 }, 
{ {19, 19, 19, 29, 29, 29, 39, 39, 39}, {34, 44, 54, 34, 44, 54, 34, 44, 54}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  574,   11 }, 
}, 
{ 
{ {0, 0, 4, 4, 8, 8, 12, 12, 0}, {12, 26, 12, 26, 12, 26, 12, 26, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1090,   18 }, 
{ {0, 0, 5, 5, 10, 10, 15, 15, 0}, {15, 32, 15, 32, 15, 32, 15, 32, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1090,   18 }, 
{ {0, 0, 6, 6, 12, 12, 18, 18, 0}, {19, 41, 19, 41, 19, 41, 19, 41, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1090,   18 }, 
{ {0, 0, 8, 8, 16, 16, 24, 24, 0}, {24, 52, 24, 52, 24, 52, 24, 52, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1090,   18 }, 
}, 
{ 
{ {15, 15, 15, 20, 20, 20, 25, 25, 25}, {9, 14, 19, 9, 14, 19, 9, 14, 19}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -135,   11 }, 
{ {20, 20, 20, 26, 26, 26, 32, 32, 32}, {12, 18, 24, 12, 18, 24, 12, 18, 24}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -135,   11 }, 
{ {25, 25, 25, 33, 33, 33, 41, 41, 41}, {15, 23, 31, 15, 23, 31, 15, 23, 31}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -135,   11 }, 
{ {32, 32, 32, 42, 42, 42, 52, 52, 52}, {19, 29, 39, 19, 29, 39, 19, 29, 39}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -135,   11 }, 
}, 
{ 
{ {18, 18, 18, 28, 28, 28, 0, 0, 0}, {4, 9, 14, 4, 9, 14, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1448,   17 }, 
{ {23, 23, 23, 36, 36, 36, 0, 0, 0}, {5, 11, 17, 5, 11, 17, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1448,   17 }, 
{ {29, 29, 29, 45, 45, 45, 0, 0, 0}, {7, 15, 23, 7, 15, 23, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1448,   17 }, 
{ {37, 37, 37, 57, 57, 57, 0, 0, 0}, {9, 19, 29, 9, 19, 29, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1448,   17 }, 
}, 
{ 
{ {9, 9, 9, 25, 25, 25, 0, 0, 0}, {0, 9, 18, 0, 9, 18, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  252,   21 }, 
{ {12, 12, 12, 33, 33, 33, 0, 0, 0}, {0, 11, 22, 0, 11, 22, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  252,   21 }, 
{ {15, 15, 15, 41, 41, 41, 0, 0, 0}, {0, 14, 28, 0, 14, 28, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  252,   21 }, 
{ {19, 19, 19, 52, 52, 52, 0, 0, 0}, {0, 18, 36, 0, 18, 36, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  252,   21 }, 
}, 
{ 
{ {20, 20, 20, 30, 30, 30, 0, 0, 0}, {0, 5, 10, 0, 5, 10, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1,  -11,   15 }, 
{ {25, 25, 25, 38, 38, 38, 0, 0, 0}, {0, 6, 12, 0, 6, 12, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1,  -11,   15 }, 
{ {32, 32, 32, 48, 48, 48, 0, 0, 0}, {0, 8, 16, 0, 8, 16, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1,  -11,   15 }, 
{ {40, 40, 40, 60, 60, 60, 0, 0, 0}, {0, 10, 20, 0, 10, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1,  -11,   15 }, 
}, 
{ 
{ {18, 18, 22, 22, 26, 26, 30, 30, 0}, {12, 30, 12, 30, 12, 30, 12, 30, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  416,   16 }, 
{ {23, 23, 28, 28, 33, 33, 38, 38, 0}, {16, 38, 16, 38, 16, 38, 16, 38, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  416,   16 }, 
{ {30, 30, 36, 36, 42, 42, 48, 48, 0}, {20, 48, 20, 48, 20, 48, 20, 48, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  416,   16 }, 
{ {36, 36, 44, 44, 52, 52, 60, 60, 0}, {25, 60, 25, 60, 25, 60, 25, 60, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  416,   16 }, 
}, 
{ 
{ {18, 18, 22, 22, 26, 26, 30, 30, 0}, {9, 23, 9, 23, 9, 23, 9, 23, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1632,   16 }, 
{ {23, 23, 28, 28, 33, 33, 38, 38, 0}, {12, 29, 12, 29, 12, 29, 12, 29, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1632,   16 }, 
{ {30, 30, 36, 36, 42, 42, 48, 48, 0}, {15, 37, 15, 37, 15, 37, 15, 37, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1632,   16 }, 
{ {36, 36, 44, 44, 52, 52, 60, 60, 0}, {19, 47, 19, 47, 19, 47, 19, 47, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -1632,   16 }, 
}, 
{ 
{ {9, 9, 9, 17, 17, 17, 25, 25, 25}, {0, 5, 10, 0, 5, 10, 0, 5, 10}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1593,   16 }, 
{ {12, 12, 12, 22, 22, 22, 32, 32, 32}, {0, 6, 12, 0, 6, 12, 0, 6, 12}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1593,   16 }, 
{ {15, 15, 15, 27, 27, 27, 39, 39, 39}, {0, 8, 16, 0, 8, 16, 0, 8, 16}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1593,   16 }, 
{ {19, 19, 19, 34, 34, 34, 49, 49, 49}, {0, 10, 20, 0, 10, 20, 0, 10, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1593,   16 }, 
}, 
{ 
{ {5, 5, 5, 10, 10, 10, 15, 15, 15}, {10, 15, 20, 10, 15, 20, 10, 15, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -742,   10 }, 
{ {7, 7, 7, 13, 13, 13, 19, 19, 19}, {13, 19, 25, 13, 19, 25, 13, 19, 25}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -742,   10 }, 
{ {9, 9, 9, 17, 17, 17, 25, 25, 25}, {17, 25, 33, 17, 25, 33, 17, 25, 33}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -742,   10 }, 
{ {12, 12, 12, 22, 22, 22, 32, 32, 32}, {22, 32, 42, 22, 32, 42, 22, 32, 42}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -742,   10 }, 
}, 
{ 
{ {0, 0, 0, 5, 5, 5, 10, 10, 10}, {2, 15, 28, 2, 15, 28, 2, 15, 28}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  653,   15 }, 
{ {0, 0, 0, 6, 6, 6, 12, 12, 12}, {2, 18, 34, 2, 18, 34, 2, 18, 34}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  653,   15 }, 
{ {0, 0, 0, 8, 8, 8, 16, 16, 16}, {3, 23, 43, 3, 23, 43, 3, 23, 43}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  653,   15 }, 
{ {0, 0, 0, 10, 10, 10, 20, 20, 20}, {4, 29, 54, 4, 29, 54, 4, 29, 54}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  653,   15 }, 
}, 
{ 
{ {3, 3, 3, 9, 9, 9, 15, 15, 15}, {12, 17, 22, 12, 17, 22, 12, 17, 22}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  485,   10 }, 
{ {4, 4, 4, 12, 12, 12, 20, 20, 20}, {15, 21, 27, 15, 21, 27, 15, 21, 27}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  485,   10 }, 
{ {5, 5, 5, 15, 15, 15, 25, 25, 25}, {19, 27, 35, 19, 27, 35, 19, 27, 35}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  485,   10 }, 
{ {7, 7, 7, 20, 20, 20, 33, 33, 33}, {24, 34, 44, 24, 34, 44, 24, 34, 44}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  485,   10 }, 
}, 
{ 
{ {0, 0, 0, 6, 6, 6, 12, 12, 12}, {0, 10, 20, 0, 10, 20, 0, 10, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -687,   17 }, 
{ {0, 0, 0, 8, 8, 8, 16, 16, 16}, {0, 13, 26, 0, 13, 26, 0, 13, 26}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -687,   17 }, 
{ {0, 0, 0, 10, 10, 10, 20, 20, 20}, {0, 16, 32, 0, 16, 32, 0, 16, 32}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -687,   17 }, 
{ {0, 0, 0, 13, 13, 13, 26, 26, 26}, {0, 20, 40, 0, 20, 40, 0, 20, 40}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -687,   17 }, 
}, 
{ 
{ {18, 18, 18, 28, 28, 28, 0, 0, 0}, {13, 18, 23, 13, 18, 23, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  411,    9 }, 
{ {23, 23, 23, 36, 36, 36, 0, 0, 0}, {16, 22, 28, 16, 22, 28, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  411,    9 }, 
{ {29, 29, 29, 45, 45, 45, 0, 0, 0}, {21, 29, 37, 21, 29, 37, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  411,    9 }, 
{ {37, 37, 37, 57, 57, 57, 0, 0, 0}, {27, 37, 47, 27, 37, 47, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  411,    9 }, 
}, 
{ 
{ {10, 10, 15, 15, 20, 20, 0, 0, 0}, {9, 28, 9, 28, 9, 28, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -674,   16 }, 
{ {13, 13, 19, 19, 25, 25, 0, 0, 0}, {12, 36, 12, 36, 12, 36, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -674,   16 }, 
{ {17, 17, 25, 25, 33, 33, 0, 0, 0}, {15, 45, 15, 45, 15, 45, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -674,   16 }, 
{ {22, 22, 32, 32, 42, 42, 0, 0, 0}, {19, 57, 19, 57, 19, 57, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -674,   16 }, 
}, 
{ 
{ {3, 3, 16, 16, 29, 29, 0, 0, 0}, {2, 30, 2, 30, 2, 30, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 2761,   18 }, 
{ {4, 4, 20, 20, 36, 36, 0, 0, 0}, {3, 38, 3, 38, 3, 38, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 2761,   18 }, 
{ {5, 5, 25, 25, 45, 45, 0, 0, 0}, {4, 48, 4, 48, 4, 48, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 2761,   18 }, 
{ {7, 7, 32, 32, 57, 57, 0, 0, 0}, {5, 60, 5, 60, 5, 60, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 2761,   18 }, 
}, 
{ 
{ {5, 5, 10, 10, 15, 15, 0, 0, 0}, {9, 20, 9, 20, 9, 20, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1,  973,   12 }, 
{ {7, 7, 13, 13, 19, 19, 0, 0, 0}, {12, 26, 12, 26, 12, 26, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1,  973,   12 }, 
{ {9, 9, 17, 17, 25, 25, 0, 0, 0}, {15, 33, 15, 33, 15, 33, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1,  973,   12 }, 
{ {12, 12, 22, 22, 32, 32, 0, 0, 0}, {19, 42, 19, 42, 19, 42, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1,  973,   12 }, 
}, 
{ 
{ {3, 3, 16, 16, 29, 29, 0, 0, 0}, {6, 30, 6, 30, 6, 30, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3419,   20 }, 
{ {4, 4, 20, 20, 36, 36, 0, 0, 0}, {8, 38, 8, 38, 8, 38, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3419,   20 }, 
{ {5, 5, 25, 25, 45, 45, 0, 0, 0}, {10, 48, 10, 48, 10, 48, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3419,   20 }, 
{ {7, 7, 32, 32, 57, 57, 0, 0, 0}, {12, 60, 12, 60, 12, 60, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3419,   20 }, 
}, 
{ 
{ {4, 4, 13, 13, 22, 22, 0, 0, 0}, {15, 25, 15, 25, 15, 25, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1,  431,   21 }, 
{ {5, 5, 16, 16, 27, 27, 0, 0, 0}, {20, 33, 20, 33, 20, 33, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1,  431,   21 }, 
{ {7, 7, 21, 21, 35, 35, 0, 0, 0}, {25, 41, 25, 41, 25, 41, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1,  431,   21 }, 
{ {9, 9, 27, 27, 45, 45, 0, 0, 0}, {32, 52, 32, 52, 32, 52, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1,  431,   21 }, 
}, 
};


const cc3_feature CC3_FACE_FEATURES4[100][4] = { 
{ 
{ {0, 0, 0, 30, 30, 30, 0, 0, 0}, {2, 16, 30, 2, 16, 30, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 28488,  115 }, 
{ {0, 0, 0, 38, 38, 38, 0, 0, 0}, {2, 19, 36, 2, 19, 36, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 28488,  115 }, 
{ {0, 0, 0, 48, 48, 48, 0, 0, 0}, {3, 25, 47, 3, 25, 47, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 28488,  115 }, 
{ {0, 0, 0, 60, 60, 60, 0, 0, 0}, {4, 32, 60, 4, 32, 60, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 28488,  115 }, 
}, 
{ 
{ {0, 0, 0, 29, 29, 29, 0, 0, 0}, {0, 15, 30, 0, 15, 30, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -24774,  111 }, 
{ {0, 0, 0, 36, 36, 36, 0, 0, 0}, {0, 19, 38, 0, 19, 38, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -24774,  111 }, 
{ {0, 0, 0, 46, 46, 46, 0, 0, 0}, {0, 24, 48, 0, 24, 48, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -24774,  111 }, 
{ {0, 0, 0, 58, 58, 58, 0, 0, 0}, {0, 30, 60, 0, 30, 60, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -24774,  111 }, 
}, 
{ 
{ {0, 0, 0, 10, 10, 10, 0, 0, 0}, {0, 5, 10, 0, 5, 10, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -436500,  123 }, 
{ {0, 0, 0, 13, 13, 13, 0, 0, 0}, {0, 6, 12, 0, 6, 12, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -436500,  123 }, 
{ {0, 0, 0, 16, 16, 16, 0, 0, 0}, {0, 8, 16, 0, 8, 16, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -436500,  123 }, 
{ {0, 0, 0, 20, 20, 20, 0, 0, 0}, {0, 10, 20, 0, 10, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -436500,  123 }, 
}, 
{ 
{ {14, 14, 14, 25, 25, 25, 0, 0, 0}, {0, 15, 30, 0, 15, 30, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 15385,  102 }, 
{ {18, 18, 18, 32, 32, 32, 0, 0, 0}, {0, 19, 38, 0, 19, 38, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 15385,  102 }, 
{ {23, 23, 23, 41, 41, 41, 0, 0, 0}, {0, 24, 48, 0, 24, 48, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 15385,  102 }, 
{ {29, 29, 29, 52, 52, 52, 0, 0, 0}, {0, 30, 60, 0, 30, 60, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 15385,  102 }, 
}, 
{ 
{ {14, 14, 14, 25, 25, 25, 0, 0, 0}, {4, 15, 26, 4, 15, 26, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -5261,   89 }, 
{ {18, 18, 18, 32, 32, 32, 0, 0, 0}, {5, 19, 33, 5, 19, 33, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -5261,   89 }, 
{ {23, 23, 23, 41, 41, 41, 0, 0, 0}, {7, 25, 43, 7, 25, 43, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -5261,   89 }, 
{ {29, 29, 29, 52, 52, 52, 0, 0, 0}, {9, 32, 55, 9, 32, 55, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -5261,   89 }, 
}, 
{ 
{ {3, 3, 3, 27, 27, 27, 0, 0, 0}, {7, 12, 17, 7, 12, 17, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -2310,   49 }, 
{ {4, 4, 4, 34, 34, 34, 0, 0, 0}, {9, 15, 21, 9, 15, 21, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -2310,   49 }, 
{ {5, 5, 5, 43, 43, 43, 0, 0, 0}, {11, 19, 27, 11, 19, 27, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -2310,   49 }, 
{ {7, 7, 7, 55, 55, 55, 0, 0, 0}, {14, 24, 34, 14, 24, 34, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -2310,   49 }, 
}, 
{ 
{ {0, 0, 0, 11, 11, 11, 0, 0, 0}, {0, 5, 10, 0, 5, 10, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -491900,  123 }, 
{ {0, 0, 0, 14, 14, 14, 0, 0, 0}, {0, 6, 12, 0, 6, 12, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -491900,  123 }, 
{ {0, 0, 0, 18, 18, 18, 0, 0, 0}, {0, 8, 16, 0, 8, 16, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -491900,  123 }, 
{ {0, 0, 0, 23, 23, 23, 0, 0, 0}, {0, 10, 20, 0, 10, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -491900,  123 }, 
}, 
{ 
{ {0, 0, 0, 30, 30, 30, 0, 0, 0}, {0, 11, 22, 0, 11, 22, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -34782,   93 }, 
{ {0, 0, 0, 38, 38, 38, 0, 0, 0}, {0, 14, 28, 0, 14, 28, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -34782,   93 }, 
{ {0, 0, 0, 48, 48, 48, 0, 0, 0}, {0, 18, 36, 0, 18, 36, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -34782,   93 }, 
{ {0, 0, 0, 60, 60, 60, 0, 0, 0}, {0, 23, 46, 0, 23, 46, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -34782,   93 }, 
}, 
{ 
{ {19, 19, 19, 29, 29, 29, 0, 0, 0}, {5, 11, 17, 5, 11, 17, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -764,   62 }, 
{ {24, 24, 24, 37, 37, 37, 0, 0, 0}, {7, 15, 23, 7, 15, 23, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -764,   62 }, 
{ {31, 31, 31, 47, 47, 47, 0, 0, 0}, {9, 19, 29, 9, 19, 29, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -764,   62 }, 
{ {39, 39, 39, 59, 59, 59, 0, 0, 0}, {12, 25, 38, 12, 25, 38, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -764,   62 }, 
}, 
{ 
{ {20, 20, 25, 25, 30, 30, 0, 0, 0}, {2, 28, 2, 28, 2, 28, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 2109,   49 }, 
{ {26, 26, 32, 32, 38, 38, 0, 0, 0}, {2, 35, 2, 35, 2, 35, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 2109,   49 }, 
{ {32, 32, 40, 40, 48, 48, 0, 0, 0}, {3, 45, 3, 45, 3, 45, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 2109,   49 }, 
{ {40, 40, 50, 50, 60, 60, 0, 0, 0}, {4, 57, 4, 57, 4, 57, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 2109,   49 }, 
}, 
{ 
{ {0, 0, 0, 10, 10, 10, 0, 0, 0}, {7, 12, 17, 7, 12, 17, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -208,   45 }, 
{ {0, 0, 0, 13, 13, 13, 0, 0, 0}, {9, 15, 21, 9, 15, 21, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -208,   45 }, 
{ {0, 0, 0, 16, 16, 16, 0, 0, 0}, {11, 19, 27, 11, 19, 27, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -208,   45 }, 
{ {0, 0, 0, 20, 20, 20, 0, 0, 0}, {14, 24, 34, 14, 24, 34, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -208,   45 }, 
}, 
{ 
{ {0, 0, 0, 13, 13, 13, 0, 0, 0}, {0, 5, 10, 0, 5, 10, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -545900,  106 }, 
{ {0, 0, 0, 16, 16, 16, 0, 0, 0}, {0, 6, 12, 0, 6, 12, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -545900,  106 }, 
{ {0, 0, 0, 20, 20, 20, 0, 0, 0}, {0, 8, 16, 0, 8, 16, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -545900,  106 }, 
{ {0, 0, 0, 25, 25, 25, 0, 0, 0}, {0, 10, 20, 0, 10, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -545900,  106 }, 
}, 
{ 
{ {15, 15, 19, 19, 23, 23, 27, 27, 0}, {4, 14, 4, 14, 4, 14, 4, 14, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -1896,   82 }, 
{ {20, 20, 25, 25, 30, 30, 35, 35, 0}, {5, 18, 5, 18, 5, 18, 5, 18, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -1896,   82 }, 
{ {25, 25, 31, 31, 37, 37, 43, 43, 0}, {7, 23, 7, 23, 7, 23, 7, 23, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -1896,   82 }, 
{ {32, 32, 40, 40, 48, 48, 56, 56, 0}, {9, 29, 9, 29, 9, 29, 9, 29, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -1896,   82 }, 
}, 
{ 
{ {17, 17, 21, 21, 25, 25, 29, 29, 0}, {2, 20, 2, 20, 2, 20, 2, 20, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 1188,   56 }, 
{ {21, 21, 26, 26, 31, 31, 36, 36, 0}, {2, 24, 2, 24, 2, 24, 2, 24, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 1188,   56 }, 
{ {27, 27, 33, 33, 39, 39, 45, 45, 0}, {3, 31, 3, 31, 3, 31, 3, 31, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 1188,   56 }, 
{ {34, 34, 42, 42, 50, 50, 58, 58, 0}, {4, 39, 4, 39, 4, 39, 4, 39, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 1188,   56 }, 
}, 
{ 
{ {2, 2, 2, 8, 8, 8, 14, 14, 14}, {2, 7, 12, 2, 7, 12, 2, 7, 12}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -402,   50 }, 
{ {2, 2, 2, 10, 10, 10, 18, 18, 18}, {2, 8, 14, 2, 8, 14, 2, 8, 14}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -402,   50 }, 
{ {3, 3, 3, 13, 13, 13, 23, 23, 23}, {3, 11, 19, 3, 11, 19, 3, 11, 19}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -402,   50 }, 
{ {4, 4, 4, 17, 17, 17, 30, 30, 30}, {4, 14, 24, 4, 14, 24, 4, 14, 24}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -402,   50 }, 
}, 
{ 
{ {15, 15, 15, 25, 25, 25, 0, 0, 0}, {13, 18, 23, 13, 18, 23, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  311,   39 }, 
{ {20, 20, 20, 33, 33, 33, 0, 0, 0}, {16, 22, 28, 16, 22, 28, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  311,   39 }, 
{ {25, 25, 25, 41, 41, 41, 0, 0, 0}, {21, 29, 37, 21, 29, 37, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  311,   39 }, 
{ {32, 32, 32, 52, 52, 52, 0, 0, 0}, {27, 37, 47, 27, 37, 47, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  311,   39 }, 
}, 
{ 
{ {9, 9, 9, 30, 30, 30, 0, 0, 0}, {14, 19, 24, 14, 19, 24, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 4468,   32 }, 
{ {11, 11, 11, 38, 38, 38, 0, 0, 0}, {18, 24, 30, 18, 24, 30, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 4468,   32 }, 
{ {14, 14, 14, 48, 48, 48, 0, 0, 0}, {23, 31, 39, 23, 31, 39, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 4468,   32 }, 
{ {17, 17, 17, 60, 60, 60, 0, 0, 0}, {29, 39, 49, 29, 39, 49, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 4468,   32 }, 
}, 
{ 
{ {0, 0, 0, 14, 14, 14, 0, 0, 0}, {0, 5, 10, 0, 5, 10, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -601300,  108 }, 
{ {0, 0, 0, 17, 17, 17, 0, 0, 0}, {0, 6, 12, 0, 6, 12, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -601300,  108 }, 
{ {0, 0, 0, 22, 22, 22, 0, 0, 0}, {0, 8, 16, 0, 8, 16, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -601300,  108 }, 
{ {0, 0, 0, 28, 28, 28, 0, 0, 0}, {0, 10, 20, 0, 10, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -601300,  108 }, 
}, 
{ 
{ {2, 2, 2, 16, 16, 16, 30, 30, 30}, {10, 16, 22, 10, 16, 22, 10, 16, 22}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -3096,   74 }, 
{ {4, 4, 4, 21, 21, 21, 38, 38, 38}, {13, 21, 29, 13, 21, 29, 13, 21, 29}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -3096,   74 }, 
{ {4, 4, 4, 26, 26, 26, 48, 48, 48}, {17, 27, 37, 17, 27, 37, 17, 27, 37}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -3096,   74 }, 
{ {4, 4, 4, 32, 32, 32, 60, 60, 60}, {22, 35, 48, 22, 35, 48, 22, 35, 48}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -3096,   74 }, 
}, 
{ 
{ {0, 0, 0, 15, 15, 15, 30, 30, 30}, {10, 15, 20, 10, 15, 20, 10, 15, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1800,   58 }, 
{ {0, 0, 0, 19, 19, 19, 38, 38, 38}, {13, 19, 25, 13, 19, 25, 13, 19, 25}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1800,   58 }, 
{ {0, 0, 0, 24, 24, 24, 48, 48, 48}, {17, 25, 33, 17, 25, 33, 17, 25, 33}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1800,   58 }, 
{ {0, 0, 0, 30, 30, 30, 60, 60, 60}, {22, 32, 42, 22, 32, 42, 22, 32, 42}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1800,   58 }, 
}, 
{ 
{ {0, 0, 5, 5, 10, 10, 0, 0, 0}, {2, 16, 2, 16, 2, 16, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -1161,   44 }, 
{ {0, 0, 6, 6, 12, 12, 0, 0, 0}, {2, 19, 2, 19, 2, 19, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -1161,   44 }, 
{ {0, 0, 8, 8, 16, 16, 0, 0, 0}, {3, 25, 3, 25, 3, 25, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -1161,   44 }, 
{ {0, 0, 10, 10, 20, 20, 0, 0, 0}, {4, 32, 4, 32, 4, 32, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -1161,   44 }, 
}, 
{ 
{ {15, 15, 15, 20, 20, 20, 25, 25, 25}, {19, 24, 29, 19, 24, 29, 19, 24, 29}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -210,   40 }, 
{ {20, 20, 20, 26, 26, 26, 32, 32, 32}, {24, 30, 36, 24, 30, 36, 24, 30, 36}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -210,   40 }, 
{ {25, 25, 25, 33, 33, 33, 41, 41, 41}, {31, 39, 47, 31, 39, 47, 31, 39, 47}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -210,   40 }, 
{ {32, 32, 32, 42, 42, 42, 52, 52, 52}, {39, 49, 59, 39, 49, 59, 39, 49, 59}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -210,   40 }, 
}, 
{ 
{ {8, 8, 8, 16, 16, 16, 24, 24, 24}, {12, 20, 28, 12, 20, 28, 12, 20, 28}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1400,   32 }, 
{ {10, 10, 10, 20, 20, 20, 30, 30, 30}, {15, 25, 35, 15, 25, 35, 15, 25, 35}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1400,   32 }, 
{ {13, 13, 13, 25, 25, 25, 37, 37, 37}, {19, 31, 43, 19, 31, 43, 19, 31, 43}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1400,   32 }, 
{ {17, 17, 17, 32, 32, 32, 47, 47, 47}, {24, 39, 54, 24, 39, 54, 24, 39, 54}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 1400,   32 }, 
}, 
{ 
{ {5, 5, 5, 14, 14, 14, 23, 23, 23}, {12, 21, 30, 12, 21, 30, 12, 21, 30}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -2492,   23 }, 
{ {7, 7, 7, 18, 18, 18, 29, 29, 29}, {15, 26, 37, 15, 26, 37, 15, 26, 37}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -2492,   23 }, 
{ {9, 9, 9, 23, 23, 23, 37, 37, 37}, {19, 33, 47, 19, 33, 47, 19, 33, 47}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -2492,   23 }, 
{ {12, 12, 12, 30, 30, 30, 48, 48, 48}, {24, 42, 60, 24, 42, 60, 24, 42, 60}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -2492,   23 }, 
}, 
{ 
{ {0, 0, 0, 15, 15, 15, 0, 0, 0}, {0, 5, 10, 0, 5, 10, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -656100,  102 }, 
{ {0, 0, 0, 19, 19, 19, 0, 0, 0}, {0, 6, 12, 0, 6, 12, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -656100,  102 }, 
{ {0, 0, 0, 24, 24, 24, 0, 0, 0}, {0, 8, 16, 0, 8, 16, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -656100,  102 }, 
{ {0, 0, 0, 30, 30, 30, 0, 0, 0}, {0, 10, 20, 0, 10, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -656100,  102 }, 
}, 
{ 
{ {0, 0, 11, 11, 22, 22, 0, 0, 0}, {1, 30, 1, 30, 1, 30, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -33231,   74 }, 
{ {0, 0, 14, 14, 28, 28, 0, 0, 0}, {2, 38, 2, 38, 2, 38, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -33231,   74 }, 
{ {0, 0, 18, 18, 36, 36, 0, 0, 0}, {2, 48, 2, 48, 2, 48, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -33231,   74 }, 
{ {0, 0, 23, 23, 46, 46, 0, 0, 0}, {2, 60, 2, 60, 2, 60, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -33231,   74 }, 
}, 
{ 
{ {0, 0, 4, 4, 8, 8, 12, 12, 0}, {15, 29, 15, 29, 15, 29, 15, 29, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  503,   46 }, 
{ {0, 0, 5, 5, 10, 10, 15, 15, 0}, {20, 37, 20, 37, 20, 37, 20, 37, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  503,   46 }, 
{ {0, 0, 6, 6, 12, 12, 18, 18, 0}, {25, 47, 25, 47, 25, 47, 25, 47, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  503,   46 }, 
{ {0, 0, 8, 8, 16, 16, 24, 24, 0}, {32, 60, 32, 60, 32, 60, 32, 60, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  503,   46 }, 
}, 
{ 
{ {10, 10, 10, 20, 20, 20, 0, 0, 0}, {2, 7, 12, 2, 7, 12, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  968,   42 }, 
{ {13, 13, 13, 26, 26, 26, 0, 0, 0}, {2, 8, 14, 2, 8, 14, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  968,   42 }, 
{ {17, 17, 17, 33, 33, 33, 0, 0, 0}, {3, 11, 19, 3, 11, 19, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  968,   42 }, 
{ {22, 22, 22, 42, 42, 42, 0, 0, 0}, {4, 14, 24, 4, 14, 24, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  968,   42 }, 
}, 
{ 
{ {7, 7, 13, 13, 19, 19, 25, 25, 0}, {7, 30, 7, 30, 7, 30, 7, 30, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 8999,   44 }, 
{ {9, 9, 17, 17, 25, 25, 33, 33, 0}, {9, 38, 9, 38, 9, 38, 9, 38, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 8999,   44 }, 
{ {11, 11, 21, 21, 31, 31, 41, 41, 0}, {12, 48, 12, 48, 12, 48, 12, 48, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 8999,   44 }, 
{ {14, 14, 27, 27, 40, 40, 53, 53, 0}, {15, 60, 15, 60, 15, 60, 15, 60, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 8999,   44 }, 
}, 
{ 
{ {0, 0, 0, 15, 15, 15, 30, 30, 30}, {0, 5, 10, 0, 5, 10, 0, 5, 10}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -2264,   27 }, 
{ {0, 0, 0, 19, 19, 19, 38, 38, 38}, {0, 6, 12, 0, 6, 12, 0, 6, 12}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -2264,   27 }, 
{ {0, 0, 0, 24, 24, 24, 48, 48, 48}, {0, 8, 16, 0, 8, 16, 0, 8, 16}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -2264,   27 }, 
{ {0, 0, 0, 30, 30, 30, 60, 60, 60}, {0, 10, 20, 0, 10, 20, 0, 10, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -2264,   27 }, 
}, 
{ 
{ {2, 2, 6, 6, 10, 10, 14, 14, 0}, {10, 23, 10, 23, 10, 23, 10, 23, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -706,   44 }, 
{ {2, 2, 7, 7, 12, 12, 17, 17, 0}, {13, 29, 13, 29, 13, 29, 13, 29, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -706,   44 }, 
{ {3, 3, 9, 9, 15, 15, 21, 21, 0}, {17, 37, 17, 37, 17, 37, 17, 37, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -706,   44 }, 
{ {4, 4, 12, 12, 20, 20, 28, 28, 0}, {22, 47, 22, 47, 22, 47, 22, 47, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -706,   44 }, 
}, 
{ 
{ {10, 10, 10, 16, 16, 16, 22, 22, 22}, {2, 7, 12, 2, 7, 12, 2, 7, 12}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  372,   30 }, 
{ {13, 13, 13, 21, 21, 21, 29, 29, 29}, {2, 8, 14, 2, 8, 14, 2, 8, 14}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  372,   30 }, 
{ {17, 17, 17, 27, 27, 27, 37, 37, 37}, {3, 11, 19, 3, 11, 19, 3, 11, 19}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  372,   30 }, 
{ {22, 22, 22, 35, 35, 35, 48, 48, 48}, {4, 14, 24, 4, 14, 24, 4, 14, 24}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  372,   30 }, 
}, 
{ 
{ {0, 0, 0, 16, 16, 16, 0, 0, 0}, {0, 5, 10, 0, 5, 10, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -711600,   92 }, 
{ {0, 0, 0, 21, 21, 21, 0, 0, 0}, {0, 6, 12, 0, 6, 12, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -711600,   92 }, 
{ {0, 0, 0, 26, 26, 26, 0, 0, 0}, {0, 8, 16, 0, 8, 16, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -711600,   92 }, 
{ {0, 0, 0, 33, 33, 33, 0, 0, 0}, {0, 10, 20, 0, 10, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -711600,   92 }, 
}, 
{ 
{ {0, 0, 15, 15, 30, 30, 0, 0, 0}, {5, 29, 5, 29, 5, 29, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, 33558,   67 }, 
{ {0, 0, 19, 19, 38, 38, 0, 0, 0}, {7, 37, 7, 37, 7, 37, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, 33558,   67 }, 
{ {0, 0, 24, 24, 48, 48, 0, 0, 0}, {9, 47, 9, 47, 9, 47, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, 33558,   67 }, 
{ {0, 0, 30, 30, 60, 60, 0, 0, 0}, {12, 60, 12, 60, 12, 60, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, 33558,   67 }, 
}, 
{ 
{ {7, 7, 7, 12, 12, 12, 17, 17, 17}, {5, 11, 17, 5, 11, 17, 5, 11, 17}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -577,   37 }, 
{ {9, 9, 9, 15, 15, 15, 21, 21, 21}, {7, 15, 23, 7, 15, 23, 7, 15, 23}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -577,   37 }, 
{ {11, 11, 11, 19, 19, 19, 27, 27, 27}, {9, 19, 29, 9, 19, 29, 9, 19, 29}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -577,   37 }, 
{ {14, 14, 14, 24, 24, 24, 34, 34, 34}, {12, 25, 38, 12, 25, 38, 12, 25, 38}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, -577,   37 }, 
}, 
{ 
{ {4, 4, 4, 14, 14, 14, 0, 0, 0}, {18, 23, 28, 18, 23, 28, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 1782,   32 }, 
{ {5, 5, 5, 18, 18, 18, 0, 0, 0}, {23, 29, 35, 23, 29, 35, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 1782,   32 }, 
{ {7, 7, 7, 23, 23, 23, 0, 0, 0}, {29, 37, 45, 29, 37, 45, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 1782,   32 }, 
{ {9, 9, 9, 29, 29, 29, 0, 0, 0}, {37, 47, 57, 37, 47, 57, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 1782,   32 }, 
}, 
{ 
{ {4, 4, 4, 14, 14, 14, 0, 0, 0}, {15, 20, 25, 15, 20, 25, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -199,   27 }, 
{ {5, 5, 5, 18, 18, 18, 0, 0, 0}, {20, 26, 32, 20, 26, 32, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -199,   27 }, 
{ {7, 7, 7, 23, 23, 23, 0, 0, 0}, {25, 33, 41, 25, 33, 41, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -199,   27 }, 
{ {9, 9, 9, 29, 29, 29, 0, 0, 0}, {32, 42, 52, 32, 42, 52, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -199,   27 }, 
}, 
{ 
{ {8, 8, 8, 24, 24, 24, 0, 0, 0}, {7, 12, 17, 7, 12, 17, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -2547,   37 }, 
{ {10, 10, 10, 31, 31, 31, 0, 0, 0}, {9, 15, 21, 9, 15, 21, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -2547,   37 }, 
{ {13, 13, 13, 39, 39, 39, 0, 0, 0}, {11, 19, 27, 11, 19, 27, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -2547,   37 }, 
{ {17, 17, 17, 50, 50, 50, 0, 0, 0}, {14, 24, 34, 14, 24, 34, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -2547,   37 }, 
}, 
{ 
{ {5, 5, 9, 9, 13, 13, 17, 17, 0}, {9, 24, 9, 24, 9, 24, 9, 24, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  418,   34 }, 
{ {7, 7, 12, 12, 17, 17, 22, 22, 0}, {12, 31, 12, 31, 12, 31, 12, 31, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  418,   34 }, 
{ {9, 9, 15, 15, 21, 21, 27, 27, 0}, {15, 39, 15, 39, 15, 39, 15, 39, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  418,   34 }, 
{ {12, 12, 20, 20, 28, 28, 36, 36, 0}, {19, 49, 19, 49, 19, 49, 19, 49, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  418,   34 }, 
}, 
{ 
{ {7, 7, 11, 11, 15, 15, 19, 19, 0}, {0, 25, 0, 25, 0, 25, 0, 25, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 3074,   25 }, 
{ {9, 9, 14, 14, 19, 19, 24, 24, 0}, {0, 32, 0, 32, 0, 32, 0, 32, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 3074,   25 }, 
{ {11, 11, 17, 17, 23, 23, 29, 29, 0}, {0, 40, 0, 40, 0, 40, 0, 40, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 3074,   25 }, 
{ {14, 14, 22, 22, 30, 30, 38, 38, 0}, {0, 50, 0, 50, 0, 50, 0, 50, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 3074,   25 }, 
}, 
{ 
{ {12, 12, 12, 18, 18, 18, 24, 24, 24}, {14, 20, 26, 14, 20, 26, 14, 20, 26}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  988,   18 }, 
{ {15, 15, 15, 23, 23, 23, 31, 31, 31}, {18, 26, 34, 18, 26, 34, 18, 26, 34}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  988,   18 }, 
{ {19, 19, 19, 29, 29, 29, 39, 39, 39}, {23, 33, 43, 23, 33, 43, 23, 33, 43}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  988,   18 }, 
{ {24, 24, 24, 37, 37, 37, 50, 50, 50}, {29, 42, 55, 29, 42, 55, 29, 42, 55}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  988,   18 }, 
}, 
{ 
{ {0, 0, 0, 18, 18, 18, 0, 0, 0}, {0, 5, 10, 0, 5, 10, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -765300,   91 }, 
{ {0, 0, 0, 22, 22, 22, 0, 0, 0}, {0, 6, 12, 0, 6, 12, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -765300,   91 }, 
{ {0, 0, 0, 28, 28, 28, 0, 0, 0}, {0, 8, 16, 0, 8, 16, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -765300,   91 }, 
{ {0, 0, 0, 35, 35, 35, 0, 0, 0}, {0, 10, 20, 0, 10, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -765300,   91 }, 
}, 
{ 
{ {0, 0, 15, 15, 30, 30, 0, 0, 0}, {4, 27, 4, 27, 4, 27, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -33536,   60 }, 
{ {0, 0, 19, 19, 38, 38, 0, 0, 0}, {5, 34, 5, 34, 5, 34, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -33536,   60 }, 
{ {0, 0, 24, 24, 48, 48, 0, 0, 0}, {7, 43, 7, 43, 7, 43, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -33536,   60 }, 
{ {0, 0, 30, 30, 60, 60, 0, 0, 0}, {9, 54, 9, 54, 9, 54, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -33536,   60 }, 
}, 
{ 
{ {4, 4, 8, 8, 12, 12, 16, 16, 0}, {0, 20, 0, 20, 0, 20, 0, 20, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -711,   36 }, 
{ {5, 5, 10, 10, 15, 15, 20, 20, 0}, {0, 25, 0, 25, 0, 25, 0, 25, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -711,   36 }, 
{ {7, 7, 13, 13, 19, 19, 25, 25, 0}, {0, 32, 0, 32, 0, 32, 0, 32, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -711,   36 }, 
{ {9, 9, 17, 17, 25, 25, 33, 33, 0}, {0, 40, 0, 40, 0, 40, 0, 40, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -711,   36 }, 
}, 
{ 
{ {7, 7, 7, 15, 15, 15, 23, 23, 23}, {0, 6, 12, 0, 6, 12, 0, 6, 12}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1497,   37 }, 
{ {9, 9, 9, 19, 19, 19, 29, 29, 29}, {0, 8, 16, 0, 8, 16, 0, 8, 16}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1497,   37 }, 
{ {11, 11, 11, 23, 23, 23, 35, 35, 35}, {0, 10, 20, 0, 10, 20, 0, 10, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1497,   37 }, 
{ {14, 14, 14, 29, 29, 29, 44, 44, 44}, {0, 13, 26, 0, 13, 26, 0, 13, 26}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1497,   37 }, 
}, 
{ 
{ {13, 13, 13, 24, 24, 24, 0, 0, 0}, {3, 8, 13, 3, 8, 13, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  614,   42 }, 
{ {16, 16, 16, 30, 30, 30, 0, 0, 0}, {4, 10, 16, 4, 10, 16, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  614,   42 }, 
{ {21, 21, 21, 39, 39, 39, 0, 0, 0}, {5, 13, 21, 5, 13, 21, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  614,   42 }, 
{ {27, 27, 27, 50, 50, 50, 0, 0, 0}, {7, 17, 27, 7, 17, 27, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  614,   42 }, 
}, 
{ 
{ {9, 9, 9, 17, 17, 17, 25, 25, 25}, {7, 16, 25, 7, 16, 25, 7, 16, 25}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -697,   32 }, 
{ {12, 12, 12, 22, 22, 22, 32, 32, 32}, {9, 20, 31, 9, 20, 31, 9, 20, 31}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -697,   32 }, 
{ {15, 15, 15, 27, 27, 27, 39, 39, 39}, {11, 25, 39, 11, 25, 39, 11, 25, 39}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -697,   32 }, 
{ {19, 19, 19, 34, 34, 34, 49, 49, 49}, {14, 32, 50, 14, 32, 50, 14, 32, 50}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -697,   32 }, 
}, 
{ 
{ {18, 18, 18, 29, 29, 29, 0, 0, 0}, {10, 19, 28, 10, 19, 28, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  512,   33 }, 
{ {23, 23, 23, 37, 37, 37, 0, 0, 0}, {13, 24, 35, 13, 24, 35, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  512,   33 }, 
{ {29, 29, 29, 47, 47, 47, 0, 0, 0}, {17, 31, 45, 17, 31, 45, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  512,   33 }, 
{ {37, 37, 37, 60, 60, 60, 0, 0, 0}, {22, 40, 58, 22, 40, 58, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  512,   33 }, 
}, 
{ 
{ {7, 7, 13, 13, 19, 19, 0, 0, 0}, {5, 15, 5, 15, 5, 15, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -421,   29 }, 
{ {9, 9, 17, 17, 25, 25, 0, 0, 0}, {7, 20, 7, 20, 7, 20, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -421,   29 }, 
{ {11, 11, 21, 21, 31, 31, 0, 0, 0}, {9, 25, 9, 25, 9, 25, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -421,   29 }, 
{ {14, 14, 27, 27, 40, 40, 0, 0, 0}, {12, 32, 12, 32, 12, 32, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -421,   29 }, 
}, 
{ 
{ {8, 8, 8, 16, 16, 16, 24, 24, 24}, {7, 13, 19, 7, 13, 19, 7, 13, 19}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  526,   27 }, 
{ {10, 10, 10, 20, 20, 20, 30, 30, 30}, {9, 17, 25, 9, 17, 25, 9, 17, 25}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  526,   27 }, 
{ {13, 13, 13, 25, 25, 25, 37, 37, 37}, {11, 21, 31, 11, 21, 31, 11, 21, 31}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  526,   27 }, 
{ {17, 17, 17, 32, 32, 32, 47, 47, 47}, {14, 27, 40, 14, 27, 40, 14, 27, 40}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  526,   27 }, 
}, 
{ 
{ {7, 7, 7, 13, 13, 13, 19, 19, 19}, {8, 14, 20, 8, 14, 20, 8, 14, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1837,   28 }, 
{ {9, 9, 9, 17, 17, 17, 25, 25, 25}, {10, 18, 26, 10, 18, 26, 10, 18, 26}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1837,   28 }, 
{ {11, 11, 11, 21, 21, 21, 31, 31, 31}, {13, 23, 33, 13, 23, 33, 13, 23, 33}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1837,   28 }, 
{ {14, 14, 14, 27, 27, 27, 40, 40, 40}, {17, 30, 43, 17, 30, 43, 17, 30, 43}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -1837,   28 }, 
}, 
{ 
{ {0, 0, 0, 10, 10, 10, 0, 0, 0}, {0, 6, 12, 0, 6, 12, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -621000,   86 }, 
{ {0, 0, 0, 13, 13, 13, 0, 0, 0}, {0, 8, 16, 0, 8, 16, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -621000,   86 }, 
{ {0, 0, 0, 16, 16, 16, 0, 0, 0}, {0, 10, 20, 0, 10, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -621000,   86 }, 
{ {0, 0, 0, 20, 20, 20, 0, 0, 0}, {0, 13, 26, 0, 13, 26, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -621000,   86 }, 
}, 
{ 
{ {0, 0, 0, 18, 18, 18, 0, 0, 0}, {14, 19, 24, 14, 19, 24, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 4717,   60 }, 
{ {0, 0, 0, 22, 22, 22, 0, 0, 0}, {18, 24, 30, 18, 24, 30, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 4717,   60 }, 
{ {0, 0, 0, 28, 28, 28, 0, 0, 0}, {23, 31, 39, 23, 31, 39, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 4717,   60 }, 
{ {0, 0, 0, 35, 35, 35, 0, 0, 0}, {29, 39, 49, 29, 39, 49, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 4717,   60 }, 
}, 
{ 
{ {0, 0, 0, 10, 10, 10, 20, 20, 20}, {19, 24, 29, 19, 24, 29, 19, 24, 29}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  868,   37 }, 
{ {0, 0, 0, 13, 13, 13, 26, 26, 26}, {24, 30, 36, 24, 30, 36, 24, 30, 36}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  868,   37 }, 
{ {0, 0, 0, 16, 16, 16, 32, 32, 32}, {31, 39, 47, 31, 39, 47, 31, 39, 47}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  868,   37 }, 
{ {0, 0, 0, 20, 20, 20, 40, 40, 40}, {39, 49, 59, 39, 49, 59, 39, 49, 59}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  868,   37 }, 
}, 
{ 
{ {20, 20, 20, 25, 25, 25, 30, 30, 30}, {12, 21, 30, 12, 21, 30, 12, 21, 30}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, 1420,   31 }, 
{ {26, 26, 26, 32, 32, 32, 38, 38, 38}, {16, 27, 38, 16, 27, 38, 16, 27, 38}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, 1420,   31 }, 
{ {32, 32, 32, 40, 40, 40, 48, 48, 48}, {20, 34, 48, 20, 34, 48, 20, 34, 48}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, 1420,   31 }, 
{ {40, 40, 40, 50, 50, 50, 60, 60, 60}, {24, 42, 60, 24, 42, 60, 24, 42, 60}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, 1420,   31 }, 
}, 
{ 
{ {8, 8, 8, 17, 17, 17, 26, 26, 26}, {0, 10, 20, 0, 10, 20, 0, 10, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 5596,   39 }, 
{ {10, 10, 10, 21, 21, 21, 32, 32, 32}, {0, 13, 26, 0, 13, 26, 0, 13, 26}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 5596,   39 }, 
{ {13, 13, 13, 27, 27, 27, 41, 41, 41}, {0, 16, 32, 0, 16, 32, 0, 16, 32}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 5596,   39 }, 
{ {17, 17, 17, 35, 35, 35, 53, 53, 53}, {0, 20, 40, 0, 20, 40, 0, 20, 40}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 5596,   39 }, 
}, 
{ 
{ {0, 0, 0, 13, 13, 13, 26, 26, 26}, {2, 12, 22, 2, 12, 22, 2, 12, 22}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -5310,   25 }, 
{ {0, 0, 0, 16, 16, 16, 32, 32, 32}, {2, 15, 28, 2, 15, 28, 2, 15, 28}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -5310,   25 }, 
{ {0, 0, 0, 20, 20, 20, 40, 40, 40}, {3, 19, 35, 3, 19, 35, 3, 19, 35}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -5310,   25 }, 
{ {0, 0, 0, 25, 25, 25, 50, 50, 50}, {4, 24, 44, 4, 24, 44, 4, 24, 44}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -5310,   25 }, 
}, 
{ 
{ {20, 20, 20, 25, 25, 25, 30, 30, 30}, {2, 7, 12, 2, 7, 12, 2, 7, 12}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  661,   39 }, 
{ {26, 26, 26, 32, 32, 32, 38, 38, 38}, {2, 8, 14, 2, 8, 14, 2, 8, 14}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  661,   39 }, 
{ {32, 32, 32, 40, 40, 40, 48, 48, 48}, {3, 11, 19, 3, 11, 19, 3, 11, 19}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  661,   39 }, 
{ {40, 40, 40, 50, 50, 50, 60, 60, 60}, {4, 14, 24, 4, 14, 24, 4, 14, 24}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  661,   39 }, 
}, 
{ 
{ {17, 17, 17, 30, 30, 30, 0, 0, 0}, {4, 9, 14, 4, 9, 14, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1690,   34 }, 
{ {22, 22, 22, 38, 38, 38, 0, 0, 0}, {5, 11, 17, 5, 11, 17, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1690,   34 }, 
{ {28, 28, 28, 48, 48, 48, 0, 0, 0}, {7, 15, 23, 7, 15, 23, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1690,   34 }, 
{ {35, 35, 35, 60, 60, 60, 0, 0, 0}, {9, 19, 29, 9, 19, 29, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -1690,   34 }, 
}, 
{ 
{ {10, 10, 14, 14, 18, 18, 22, 22, 0}, {17, 30, 17, 30, 17, 30, 17, 30, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -574,   32 }, 
{ {13, 13, 18, 18, 23, 23, 28, 28, 0}, {21, 37, 21, 37, 21, 37, 21, 37, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -574,   32 }, 
{ {17, 17, 23, 23, 29, 29, 35, 35, 0}, {27, 47, 27, 47, 27, 47, 27, 47, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -574,   32 }, 
{ {22, 22, 30, 30, 38, 38, 46, 46, 0}, {34, 59, 34, 59, 34, 59, 34, 59, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -574,   32 }, 
}, 
{ 
{ {5, 5, 5, 15, 15, 15, 0, 0, 0}, {4, 15, 26, 4, 15, 26, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -3132,   27 }, 
{ {7, 7, 7, 20, 20, 20, 0, 0, 0}, {5, 19, 33, 5, 19, 33, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -3132,   27 }, 
{ {9, 9, 9, 25, 25, 25, 0, 0, 0}, {7, 25, 43, 7, 25, 43, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -3132,   27 }, 
{ {12, 12, 12, 32, 32, 32, 0, 0, 0}, {9, 32, 55, 9, 32, 55, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -3132,   27 }, 
}, 
{ 
{ {4, 4, 4, 17, 17, 17, 30, 30, 30}, {5, 10, 15, 5, 10, 15, 5, 10, 15}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  557,   27 }, 
{ {5, 5, 5, 21, 21, 21, 37, 37, 37}, {7, 13, 19, 7, 13, 19, 7, 13, 19}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  557,   27 }, 
{ {7, 7, 7, 27, 27, 27, 47, 47, 47}, {9, 17, 25, 9, 17, 25, 9, 17, 25}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  557,   27 }, 
{ {9, 9, 9, 34, 34, 34, 59, 59, 59}, {12, 22, 32, 12, 22, 32, 12, 22, 32}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  557,   27 }, 
}, 
{ 
{ {8, 8, 8, 18, 18, 18, 0, 0, 0}, {7, 17, 27, 7, 17, 27, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 2170,   21 }, 
{ {10, 10, 10, 23, 23, 23, 0, 0, 0}, {9, 22, 35, 9, 22, 35, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 2170,   21 }, 
{ {13, 13, 13, 29, 29, 29, 0, 0, 0}, {11, 27, 43, 11, 27, 43, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 2170,   21 }, 
{ {17, 17, 17, 37, 37, 37, 0, 0, 0}, {14, 34, 54, 14, 34, 54, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 2170,   21 }, 
}, 
{ 
{ {0, 0, 4, 4, 8, 8, 12, 12, 0}, {13, 23, 13, 23, 13, 23, 13, 23, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,   34,   35 }, 
{ {0, 0, 5, 5, 10, 10, 15, 15, 0}, {16, 29, 16, 29, 16, 29, 16, 29, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,   34,   35 }, 
{ {0, 0, 6, 6, 12, 12, 18, 18, 0}, {21, 37, 21, 37, 21, 37, 21, 37, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,   34,   35 }, 
{ {0, 0, 8, 8, 16, 16, 24, 24, 0}, {27, 47, 27, 47, 27, 47, 27, 47, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,   34,   35 }, 
}, 
{ 
{ {5, 5, 9, 9, 13, 13, 17, 17, 0}, {9, 23, 9, 23, 9, 23, 9, 23, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  537,   34 }, 
{ {7, 7, 12, 12, 17, 17, 22, 22, 0}, {12, 29, 12, 29, 12, 29, 12, 29, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  537,   34 }, 
{ {9, 9, 15, 15, 21, 21, 27, 27, 0}, {15, 37, 15, 37, 15, 37, 15, 37, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  537,   34 }, 
{ {12, 12, 20, 20, 28, 28, 36, 36, 0}, {19, 47, 19, 47, 19, 47, 19, 47, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  537,   34 }, 
}, 
{ 
{ {0, 0, 8, 8, 16, 16, 24, 24, 0}, {4, 29, 4, 29, 4, 29, 4, 29, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -4911,   41 }, 
{ {0, 0, 10, 10, 20, 20, 30, 30, 0}, {5, 37, 5, 37, 5, 37, 5, 37, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -4911,   41 }, 
{ {0, 0, 12, 12, 24, 24, 36, 36, 0}, {7, 47, 7, 47, 7, 47, 7, 47, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -4911,   41 }, 
{ {0, 0, 15, 15, 30, 30, 45, 45, 0}, {9, 59, 9, 59, 9, 59, 9, 59, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -4911,   41 }, 
}, 
{ 
{ {8, 8, 12, 12, 16, 16, 20, 20, 0}, {9, 30, 9, 30, 9, 30, 9, 30, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -1526,   31 }, 
{ {10, 10, 15, 15, 20, 20, 25, 25, 0}, {11, 38, 11, 38, 11, 38, 11, 38, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -1526,   31 }, 
{ {13, 13, 19, 19, 25, 25, 31, 31, 0}, {14, 48, 14, 48, 14, 48, 14, 48, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -1526,   31 }, 
{ {17, 17, 25, 25, 33, 33, 41, 41, 0}, {17, 60, 17, 60, 17, 60, 17, 60, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -1526,   31 }, 
}, 
{ 
{ {4, 4, 4, 23, 23, 23, 0, 0, 0}, {12, 17, 22, 12, 17, 22, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  552,   26 }, 
{ {5, 5, 5, 29, 29, 29, 0, 0, 0}, {15, 21, 27, 15, 21, 27, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  552,   26 }, 
{ {7, 7, 7, 37, 37, 37, 0, 0, 0}, {19, 27, 35, 19, 27, 35, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  552,   26 }, 
{ {9, 9, 9, 47, 47, 47, 0, 0, 0}, {24, 34, 44, 24, 34, 44, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  552,   26 }, 
}, 
{ 
{ {8, 8, 8, 19, 19, 19, 0, 0, 0}, {8, 16, 24, 8, 16, 24, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 2598,   19 }, 
{ {10, 10, 10, 24, 24, 24, 0, 0, 0}, {10, 20, 30, 10, 20, 30, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 2598,   19 }, 
{ {13, 13, 13, 31, 31, 31, 0, 0, 0}, {13, 25, 37, 13, 25, 37, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 2598,   19 }, 
{ {17, 17, 17, 40, 40, 40, 0, 0, 0}, {17, 32, 47, 17, 32, 47, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 2598,   19 }, 
}, 
{ 
{ {9, 9, 9, 19, 19, 19, 29, 29, 29}, {8, 14, 20, 8, 14, 20, 8, 14, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -679,   14 }, 
{ {12, 12, 12, 25, 25, 25, 38, 38, 38}, {10, 18, 26, 10, 18, 26, 10, 18, 26}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -679,   14 }, 
{ {15, 15, 15, 31, 31, 31, 47, 47, 47}, {13, 23, 33, 13, 23, 33, 13, 23, 33}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -679,   14 }, 
{ {19, 19, 19, 39, 39, 39, 59, 59, 59}, {17, 30, 43, 17, 30, 43, 17, 30, 43}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -679,   14 }, 
}, 
{ 
{ {0, 0, 0, 10, 10, 10, 0, 0, 0}, {0, 8, 16, 0, 8, 16, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -758300,   81 }, 
{ {0, 0, 0, 13, 13, 13, 0, 0, 0}, {0, 10, 20, 0, 10, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -758300,   81 }, 
{ {0, 0, 0, 16, 16, 16, 0, 0, 0}, {0, 12, 24, 0, 12, 24, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -758300,   81 }, 
{ {0, 0, 0, 20, 20, 20, 0, 0, 0}, {0, 15, 30, 0, 15, 30, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -758300,   81 }, 
}, 
{ 
{ {9, 9, 13, 13, 17, 17, 21, 21, 0}, {20, 30, 20, 30, 20, 30, 20, 30, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 1994,   53 }, 
{ {12, 12, 17, 17, 22, 22, 27, 27, 0}, {25, 38, 25, 38, 25, 38, 25, 38, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 1994,   53 }, 
{ {15, 15, 21, 21, 27, 27, 33, 33, 0}, {32, 48, 32, 48, 32, 48, 32, 48, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 1994,   53 }, 
{ {19, 19, 27, 27, 35, 35, 43, 43, 0}, {40, 60, 40, 60, 40, 60, 40, 60, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 1994,   53 }, 
}, 
{ 
{ {7, 7, 12, 12, 17, 17, 0, 0, 0}, {14, 24, 14, 24, 14, 24, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1,    7,   31 }, 
{ {9, 9, 15, 15, 21, 21, 0, 0, 0}, {18, 31, 18, 31, 18, 31, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1,    7,   31 }, 
{ {11, 11, 19, 19, 27, 27, 0, 0, 0}, {23, 39, 23, 39, 23, 39, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1,    7,   31 }, 
{ {14, 14, 24, 24, 34, 34, 0, 0, 0}, {29, 49, 29, 49, 29, 49, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1,    7,   31 }, 
}, 
{ 
{ {13, 13, 19, 19, 25, 25, 0, 0, 0}, {14, 27, 14, 27, 14, 27, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -239,   31 }, 
{ {16, 16, 24, 24, 32, 32, 0, 0, 0}, {18, 34, 18, 34, 18, 34, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -239,   31 }, 
{ {21, 21, 31, 31, 41, 41, 0, 0, 0}, {23, 43, 23, 43, 23, 43, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -239,   31 }, 
{ {27, 27, 40, 40, 53, 53, 0, 0, 0}, {29, 54, 29, 54, 29, 54, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -239,   31 }, 
}, 
{ 
{ {12, 12, 20, 20, 28, 28, 0, 0, 0}, {13, 27, 13, 27, 13, 27, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 1333,   34 }, 
{ {15, 15, 25, 25, 35, 35, 0, 0, 0}, {16, 33, 16, 33, 16, 33, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 1333,   34 }, 
{ {19, 19, 31, 31, 43, 43, 0, 0, 0}, {21, 43, 21, 43, 21, 43, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 1333,   34 }, 
{ {24, 24, 39, 39, 54, 54, 0, 0, 0}, {27, 55, 27, 55, 27, 55, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, 1333,   34 }, 
}, 
{ 
{ {4, 4, 4, 15, 15, 15, 26, 26, 26}, {17, 22, 27, 17, 22, 27, 17, 22, 27}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 2596,   37 }, 
{ {5, 5, 5, 19, 19, 19, 33, 33, 33}, {21, 27, 33, 21, 27, 33, 21, 27, 33}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 2596,   37 }, 
{ {7, 7, 7, 25, 25, 25, 43, 43, 43}, {27, 35, 43, 27, 35, 43, 27, 35, 43}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 2596,   37 }, 
{ {9, 9, 9, 32, 32, 32, 55, 55, 55}, {34, 44, 54, 34, 44, 54, 34, 44, 54}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 2596,   37 }, 
}, 
{ 
{ {10, 10, 10, 15, 15, 15, 20, 20, 20}, {15, 20, 25, 15, 20, 25, 15, 20, 25}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -600,   26 }, 
{ {13, 13, 13, 19, 19, 19, 25, 25, 25}, {20, 26, 32, 20, 26, 32, 20, 26, 32}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -600,   26 }, 
{ {17, 17, 17, 25, 25, 25, 33, 33, 33}, {25, 33, 41, 25, 33, 41, 25, 33, 41}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -600,   26 }, 
{ {22, 22, 22, 32, 32, 32, 42, 42, 42}, {32, 42, 52, 32, 42, 52, 32, 42, 52}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -600,   26 }, 
}, 
{ 
{ {2, 2, 16, 16, 30, 30, 0, 0, 0}, {7, 30, 7, 30, 7, 30, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3231,   38 }, 
{ {2, 2, 19, 19, 36, 36, 0, 0, 0}, {9, 38, 9, 38, 9, 38, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3231,   38 }, 
{ {3, 3, 25, 25, 47, 47, 0, 0, 0}, {11, 47, 11, 47, 11, 47, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3231,   38 }, 
{ {4, 4, 32, 32, 60, 60, 0, 0, 0}, {14, 59, 14, 59, 14, 59, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3231,   38 }, 
}, 
{ 
{ {12, 12, 17, 17, 22, 22, 0, 0, 0}, {19, 30, 19, 30, 19, 30, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1,  585,   34 }, 
{ {15, 15, 21, 21, 27, 27, 0, 0, 0}, {24, 38, 24, 38, 24, 38, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1,  585,   34 }, 
{ {19, 19, 27, 27, 35, 35, 0, 0, 0}, {30, 48, 30, 48, 30, 48, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1,  585,   34 }, 
{ {24, 24, 34, 34, 44, 44, 0, 0, 0}, {37, 60, 37, 60, 37, 60, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1,  585,   34 }, 
}, 
{ 
{ {0, 0, 0, 8, 8, 8, 16, 16, 16}, {0, 15, 30, 0, 15, 30, 0, 15, 30}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  347,   27 }, 
{ {0, 0, 0, 10, 10, 10, 20, 20, 20}, {0, 19, 38, 0, 19, 38, 0, 19, 38}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  347,   27 }, 
{ {0, 0, 0, 12, 12, 12, 24, 24, 24}, {0, 24, 48, 0, 24, 48, 0, 24, 48}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  347,   27 }, 
{ {0, 0, 0, 15, 15, 15, 30, 30, 30}, {0, 30, 60, 0, 30, 60, 0, 30, 60}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  347,   27 }, 
}, 
{ 
{ {0, 0, 0, 10, 10, 10, 0, 0, 0}, {14, 19, 24, 14, 19, 24, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -342,   26 }, 
{ {0, 0, 0, 13, 13, 13, 0, 0, 0}, {18, 24, 30, 18, 24, 30, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -342,   26 }, 
{ {0, 0, 0, 16, 16, 16, 0, 0, 0}, {23, 31, 39, 23, 31, 39, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -342,   26 }, 
{ {0, 0, 0, 20, 20, 20, 0, 0, 0}, {29, 39, 49, 29, 39, 49, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1, -342,   26 }, 
}, 
{ 
{ {13, 13, 17, 17, 21, 21, 25, 25, 0}, {4, 17, 4, 17, 4, 17, 4, 17, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  254,   27 }, 
{ {16, 16, 21, 21, 26, 26, 31, 31, 0}, {5, 21, 5, 21, 5, 21, 5, 21, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  254,   27 }, 
{ {21, 21, 27, 27, 33, 33, 39, 39, 0}, {7, 27, 7, 27, 7, 27, 7, 27, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  254,   27 }, 
{ {27, 27, 35, 35, 43, 43, 51, 51, 0}, {9, 34, 9, 34, 9, 34, 9, 34, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  254,   27 }, 
}, 
{ 
{ {7, 7, 11, 11, 15, 15, 19, 19, 0}, {9, 24, 9, 24, 9, 24, 9, 24, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  149,   29 }, 
{ {9, 9, 14, 14, 19, 19, 24, 24, 0}, {12, 31, 12, 31, 12, 31, 12, 31, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  149,   29 }, 
{ {11, 11, 17, 17, 23, 23, 29, 29, 0}, {15, 39, 15, 39, 15, 39, 15, 39, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  149,   29 }, 
{ {14, 14, 22, 22, 30, 30, 38, 38, 0}, {19, 49, 19, 49, 19, 49, 19, 49, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  149,   29 }, 
}, 
{ 
{ {2, 2, 2, 7, 7, 7, 12, 12, 12}, {7, 12, 17, 7, 12, 17, 7, 12, 17}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  401,   28 }, 
{ {2, 2, 2, 8, 8, 8, 14, 14, 14}, {9, 15, 21, 9, 15, 21, 9, 15, 21}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  401,   28 }, 
{ {3, 3, 3, 11, 11, 11, 19, 19, 19}, {11, 19, 27, 11, 19, 27, 11, 19, 27}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  401,   28 }, 
{ {4, 4, 4, 14, 14, 14, 24, 24, 24}, {14, 24, 34, 14, 24, 34, 14, 24, 34}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1,  401,   28 }, 
}, 
{ 
{ {3, 3, 7, 7, 11, 11, 15, 15, 0}, {7, 22, 7, 22, 7, 22, 7, 22, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -899,   22 }, 
{ {4, 4, 9, 9, 14, 14, 19, 19, 0}, {9, 28, 9, 28, 9, 28, 9, 28, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -899,   22 }, 
{ {5, 5, 11, 11, 17, 17, 23, 23, 0}, {11, 35, 11, 35, 11, 35, 11, 35, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -899,   22 }, 
{ {7, 7, 15, 15, 23, 23, 31, 31, 0}, {14, 44, 14, 44, 14, 44, 14, 44, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1, -899,   22 }, 
}, 
{ 
{ {7, 7, 7, 18, 18, 18, 29, 29, 29}, {0, 5, 10, 0, 5, 10, 0, 5, 10}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 3022,   15 }, 
{ {9, 9, 9, 23, 23, 23, 37, 37, 37}, {0, 6, 12, 0, 6, 12, 0, 6, 12}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 3022,   15 }, 
{ {11, 11, 11, 29, 29, 29, 47, 47, 47}, {0, 8, 16, 0, 8, 16, 0, 8, 16}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 3022,   15 }, 
{ {14, 14, 14, 37, 37, 37, 60, 60, 60}, {0, 10, 20, 0, 10, 20, 0, 10, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 3022,   15 }, 
}, 
{ 
{ {8, 8, 13, 13, 18, 18, 0, 0, 0}, {5, 15, 5, 15, 5, 15, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -1890,   19 }, 
{ {10, 10, 16, 16, 22, 22, 0, 0, 0}, {7, 20, 7, 20, 7, 20, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -1890,   19 }, 
{ {13, 13, 21, 21, 29, 29, 0, 0, 0}, {9, 25, 9, 25, 9, 25, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -1890,   19 }, 
{ {17, 17, 27, 27, 37, 37, 0, 0, 0}, {12, 32, 12, 32, 12, 32, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1, -1890,   19 }, 
}, 
{ 
{ {0, 0, 0, 11, 11, 11, 0, 0, 0}, {0, 8, 16, 0, 8, 16, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -855100,   81 }, 
{ {0, 0, 0, 14, 14, 14, 0, 0, 0}, {0, 10, 20, 0, 10, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -855100,   81 }, 
{ {0, 0, 0, 18, 18, 18, 0, 0, 0}, {0, 12, 24, 0, 12, 24, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -855100,   81 }, 
{ {0, 0, 0, 23, 23, 23, 0, 0, 0}, {0, 15, 30, 0, 15, 30, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, -855100,   81 }, 
}, 
{ 
{ {14, 14, 18, 18, 22, 22, 26, 26, 0}, {0, 18, 0, 18, 0, 18, 0, 18, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 5099,   54 }, 
{ {18, 18, 23, 23, 28, 28, 33, 33, 0}, {0, 22, 0, 22, 0, 22, 0, 22, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 5099,   54 }, 
{ {23, 23, 29, 29, 35, 35, 41, 41, 0}, {0, 28, 0, 28, 0, 28, 0, 28, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 5099,   54 }, 
{ {29, 29, 37, 37, 45, 45, 53, 53, 0}, {0, 35, 0, 35, 0, 35, 0, 35, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, 5099,   54 }, 
}, 
{ 
{ {15, 15, 19, 19, 23, 23, 27, 27, 0}, {0, 15, 0, 15, 0, 15, 0, 15, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  289,   32 }, 
{ {20, 20, 25, 25, 30, 30, 35, 35, 0}, {0, 19, 0, 19, 0, 19, 0, 19, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  289,   32 }, 
{ {25, 25, 31, 31, 37, 37, 43, 43, 0}, {0, 24, 0, 24, 0, 24, 0, 24, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  289,   32 }, 
{ {32, 32, 40, 40, 48, 48, 56, 56, 0}, {0, 30, 0, 30, 0, 30, 0, 30, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  289,   32 }, 
}, 
{ 
{ {17, 17, 21, 21, 25, 25, 29, 29, 0}, {5, 19, 5, 19, 5, 19, 5, 19, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -601,   32 }, 
{ {21, 21, 26, 26, 31, 31, 36, 36, 0}, {7, 24, 7, 24, 7, 24, 7, 24, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -601,   32 }, 
{ {27, 27, 33, 33, 39, 39, 45, 45, 0}, {9, 31, 9, 31, 9, 31, 9, 31, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -601,   32 }, 
{ {34, 34, 42, 42, 50, 50, 58, 58, 0}, {12, 40, 12, 40, 12, 40, 12, 40, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -601,   32 }, 
}, 
{ 
{ {0, 0, 0, 14, 14, 14, 28, 28, 28}, {0, 5, 10, 0, 5, 10, 0, 5, 10}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -2180,   31 }, 
{ {0, 0, 0, 17, 17, 17, 34, 34, 34}, {0, 6, 12, 0, 6, 12, 0, 6, 12}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -2180,   31 }, 
{ {0, 0, 0, 22, 22, 22, 44, 44, 44}, {0, 8, 16, 0, 8, 16, 0, 8, 16}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -2180,   31 }, 
{ {0, 0, 0, 28, 28, 28, 56, 56, 56}, {0, 10, 20, 0, 10, 20, 0, 10, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, -1, -2180,   31 }, 
}, 
{ 
{ {18, 18, 22, 22, 26, 26, 30, 30, 0}, {17, 30, 17, 30, 17, 30, 17, 30, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  215,   30 }, 
{ {23, 23, 28, 28, 33, 33, 38, 38, 0}, {22, 38, 22, 38, 22, 38, 22, 38, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  215,   30 }, 
{ {29, 29, 35, 35, 41, 41, 47, 47, 0}, {28, 48, 28, 48, 28, 48, 28, 48, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  215,   30 }, 
{ {36, 36, 44, 44, 52, 52, 60, 60, 0}, {35, 60, 35, 60, 35, 60, 35, 60, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, -1,  215,   30 }, 
}, 
{ 
{ {18, 18, 22, 22, 26, 26, 30, 30, 0}, {14, 30, 14, 30, 14, 30, 14, 30, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -817,   33 }, 
{ {23, 23, 28, 28, 33, 33, 38, 38, 0}, {17, 38, 17, 38, 17, 38, 17, 38, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -817,   33 }, 
{ {30, 30, 36, 36, 42, 42, 48, 48, 0}, {22, 48, 22, 48, 22, 48, 22, 48, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -817,   33 }, 
{ {36, 36, 44, 44, 52, 52, 60, 60, 0}, {27, 60, 27, 60, 27, 60, 27, 60, 0}, {1, -1, -3, 3, 3, -3, -1, 1, 0}, 1, -817,   33 }, 
}, 
{ 
{ {2, 2, 2, 15, 15, 15, 28, 28, 28}, {0, 6, 12, 0, 6, 12, 0, 6, 12}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 3176,   33 }, 
{ {2, 2, 2, 18, 18, 18, 34, 34, 34}, {0, 8, 16, 0, 8, 16, 0, 8, 16}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 3176,   33 }, 
{ {3, 3, 3, 23, 23, 23, 43, 43, 43}, {0, 10, 20, 0, 10, 20, 0, 10, 20}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 3176,   33 }, 
{ {4, 4, 4, 29, 29, 29, 54, 54, 54}, {0, 13, 26, 0, 13, 26, 0, 13, 26}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1, 3176,   33 }, 
}, 
{ 
{ {3, 3, 13, 13, 23, 23, 0, 0, 0}, {12, 30, 12, 30, 12, 30, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3703,   35 }, 
{ {4, 4, 17, 17, 30, 30, 0, 0, 0}, {15, 37, 15, 37, 15, 37, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3703,   35 }, 
{ {5, 5, 21, 21, 37, 37, 0, 0, 0}, {19, 47, 19, 47, 19, 47, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3703,   35 }, 
{ {7, 7, 27, 27, 47, 47, 0, 0, 0}, {24, 59, 24, 59, 24, 59, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, 1, -3703,   35 }, 
}, 
{ 
{ {5, 5, 13, 13, 21, 21, 0, 0, 0}, {13, 26, 13, 26, 13, 26, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1,  819,   34 }, 
{ {7, 7, 17, 17, 27, 27, 0, 0, 0}, {16, 32, 16, 32, 16, 32, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1,  819,   34 }, 
{ {9, 9, 21, 21, 33, 33, 0, 0, 0}, {21, 41, 21, 41, 21, 41, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1,  819,   34 }, 
{ {12, 12, 27, 27, 42, 42, 0, 0, 0}, {27, 52, 27, 52, 27, 52, 0, 0, 0}, {1, -1, -2, 2, 1, -1, 0, 0, 0}, -1,  819,   34 }, 
}, 
{ 
{ {13, 13, 13, 28, 28, 28, 0, 0, 0}, {13, 18, 23, 13, 18, 23, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 3468,   28 }, 
{ {16, 16, 16, 35, 35, 35, 0, 0, 0}, {16, 22, 28, 16, 22, 28, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 3468,   28 }, 
{ {21, 21, 21, 45, 45, 45, 0, 0, 0}, {21, 29, 37, 21, 29, 37, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 3468,   28 }, 
{ {27, 27, 27, 57, 57, 57, 0, 0, 0}, {27, 37, 47, 27, 37, 47, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, 1, 3468,   28 }, 
}, 
{ 
{ {0, 0, 0, 14, 14, 14, 28, 28, 28}, {12, 17, 22, 12, 17, 22, 12, 17, 22}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  231,   31 }, 
{ {0, 0, 0, 17, 17, 17, 34, 34, 34}, {15, 21, 27, 15, 21, 27, 15, 21, 27}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  231,   31 }, 
{ {0, 0, 0, 22, 22, 22, 44, 44, 44}, {19, 27, 35, 19, 27, 35, 19, 27, 35}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  231,   31 }, 
{ {0, 0, 0, 28, 28, 28, 56, 56, 56}, {24, 34, 44, 24, 34, 44, 24, 34, 44}, {1, -2, 1, -2, 4, -2, 1, -2, 1}, 1,  231,   31 }, 
}, 
{ 
{ {4, 4, 4, 14, 14, 14, 0, 0, 0}, {10, 15, 20, 10, 15, 20, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  442,   32 }, 
{ {5, 5, 5, 18, 18, 18, 0, 0, 0}, {13, 19, 25, 13, 19, 25, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  442,   32 }, 
{ {7, 7, 7, 23, 23, 23, 0, 0, 0}, {17, 25, 33, 17, 25, 33, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  442,   32 }, 
{ {9, 9, 9, 29, 29, 29, 0, 0, 0}, {22, 32, 42, 22, 32, 42, 0, 0, 0}, {1, -2, 1, -1, 2, -1, 0, 0, 0}, -1,  442,   32 }, 
}, 
};


/*----------------------------------------*/
/*          Declaring functions           */
/*----------------------------------------*/

/* function to get the current segment from the actual image  */
void cc3_get_curr_segment(void);

/* function to get the integral image for the current segment  */
void cc3_get_integral_image(void);

/* function to get the val of feat for a sub-window */
int16_t cc3_get_feat_val(uint8_t feat_num, uint8_t curr_scale, uint16_t x, uint16_t y);

#endif
